All Classes and Interfaces

Class
Description
Abstract implementation of the Annotated contract.
Implementation of AnnotatedCallable interface.
Base class for all bean builders
Abstract implementation of the Context interfaces.
 
 
 
 
 
Abstract implementation of all components which are injectable.
 
 
 
Abstract implementation of the OwbBean contract.
 
Abstract class for producer components.
AbstractProducerBeanBuilder<T,A extends jakarta.enterprise.inject.spi.AnnotatedMember<?>,P extends AbstractProducerBean<T>>
 
Base class for all OWB Proxy factories
 
 
 
Event that is fired by the container after it discovers beans.
Event that is fired by the container after it validates deployment.
An lifecycle event implementing this API will have this callback after each observer.
OWB fires this event after all AnnotatedTypes from scanned classes got picked up.
This class has 2 responsibilities. 1.) to collect information about configured @Alternatives at boot time 2.) answer if a class is an enabled Alternative.
 
Implementation of AnnotatedConstructor interface.
Factory for Annotated elements.
 
Implementation of AnnotatedField interface.
 
Implementation of AnnotatedMethod interface.
 
Implementation of AnnotatedParameter interface.
Hold information for lifecycle Events which can modify or add multiple AnnotatedTypeConfigurator
 
Implementation of the AnnotatedType interface.
 
Manages annotation usage by classes in this application.
Utility class related with Annotation operations.
 
Application context implementation.
This is a Provider especially made for @ApplicationScoped beans.
RequestScoped literal annotation.
 
Simple utility classes with some assertions methods.
 
 
 
Filter which knows about BeanArchive scan modes
BeanAttributesBuilder<T,A extends jakarta.enterprise.inject.spi.Annotated>
Abstract implementation.
 
 
 
 
 
Stores the CreationalContext and the Contextual Instance.
 
Implementation of the BeanManager contract of the web beans container.
 
Implicit metadata bean definition.
 
Deploys the all beans that are defined in the ScannerService at the scanner phase.
 
Events that is fired before container starts to discover beans.
Destroyed literal.
Event that is fired by the container before it shuts down.
 
 
this delegate pattern is interesting because we will be able to add some exclusion config through it using Filter + FilterArchive
 
Interceptor Bean implementation for CDI-style Beans.
Bean builder for InterceptorBeans.
 
 
 
 
Utility classes with respect to the class operations.
 
 
 
Conversation bean implementation.
Conversation context implementation.
Implementation of the Conversation interface.
Manager for the conversations.
Producer for &#064;Inject Conversation;
Bean used to create the map of conversations in a session
Factory for CreationalContext instances.
Wrapper for custom AlterableContexts
 
 
 
Decorator Bean implementation.
Bean builder for InterceptorBeans.
 
InterceptorHandler which handles all the Decorators on the InjectionTarget.
 
Implicit metadata bean definition.
 
A small helper class to create a Annotation instance of the given annotation class via Proxy.
Really simple default impl of the ApplicationBoundaryService.
Tracks contents of each BDA's beans.xml to determine the interceptor, alternative, decorator, or etc that is applicable for a given BDA.
 
Please note that this implementation is not thread safe.
 
We do not support Conversation propagation in JavaSE yet.
Enables to elect an annotated (field, constructor, method) as having (virtually) @Inject.
 
SPI Implementation of the JNDIService.
Default literal annotation.
Default implementation which delegates to the sServiceLoader.
 
 
Defines the component Dependent context.
This class contains creation information about @Dependent scoped contextual instances.
Dependent literal annotation.
 
 
This interface defines an exception which can later get catched and an additional description can be added.
Destroyed literal.
 
Interceptor Bean implementation for EJB-style Beans.
Bean builder for InterceptorBeans.
 
The ELContextStore serves two different purposes Store Dependent objects of the same invocation.
 
Base class for AnnotationLiterals which have no members.
Marker interface for enterprise beans.
Error stack.
 
Implicit observable bean definition.
 
Event implementation.
Implicit event metadata bean definition.
 
 
 
 
 
 
Extension service bean definition.
ExtensionBeanBuilder<T extends jakarta.enterprise.inject.spi.Extension>
 
Loads META-INF/services/jakarta.enterprise.inject.spi.Extension services.
 
A factory for Producers that produce CDI Extensions.
A wrapper for an external scope which can be added by BeforeBeanDiscovery.addScope(Class, boolean, boolean).
 
 
 
Utility classes for generic type operations.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Initialized literal.
This implementation of the BeanManager will get used for whenever a BeanManager gets injected into a bean:
Injects the parameters of the ManagedBean constructor and returns the created instance.
Field type injection.
 
 
 
 
 
 
 
Injection point resolver class.
Abstract class for injection target beans.
 
 
 
Implements the Instance interface.
 
Marker interface for beans that can be intercepted.
Implicit metadata bean definition.
 
 
 
Abstract Interceptor Bean implementation.
An InvocationContext wraper for handling multiple interceptor methods.
Bean builder for InterceptorBeans.
 
Generate a dynamic subclass which has exactly 1 delegation point instance which get's set in the Constructor of the proxy.
An InterceptorHandler can be used to dynamically invoke methods on an internally stored target instance.
 
InvocationContext for business method interceptors
Implicit metadata bean definition.
Class to calculate interceptor resolution information.
static information about interceptors and decorators for a single bean.
We track per method which Interceptors to invoke
Class-scoped CDI interceptors and their effective interceptor bindings.
 
Business-method interceptors plus per-method CDI InvocationContext bindings.
This class keeps all the enabled interceptor classes information of a certain BeanManager.
 
InvokerBuilder for portable extensions (ProcessManagedBean / ProcessSessionBean).
Invoker that delegates to Method.invoke(java.lang.Object, java.lang.Object...), optionally performing CDI lookups.
Stereotype model contract.
 
 
 
This is the internal helper class for low level access to JNDI
 
 
InvocationContext for lifecycle methods like @PostConstruct, etc.
Managed bean implementation of the Bean.
Bean builder for Managed Beans.
This version of the SecurityService uses the java.lang.SecurityManager to check low level access to the underlying functions via doPriviliged blocks.
 
 
 
 
 
 
 
 
 
 
Named literal.
A Provider which handles all NormalScoped proxying.
This factory creates proxies which delegate the method invocations 1:1 to an instance which gets resolved via a Provider.
 
 
Defines observers that are declared in observer methods.
 
Defines configuration for OpenWebBeans.
 
 
Used by each test.
We just extend the default AnnotationFinder to get Access to the original ClassInfo for not having to call loadClass so often...
OWB specific extension of the Bean interface.
 
 
 
Interface for all OpenWebBeans abstract Decorator subclasses.
 
Injects dependencies of the given Java EE component instance.
Marker Interface for all OpenWebBeans Interceptor+Decorator Proxies.
 
Interface for all OpenWebBeans NormalScope Proxies.
This interface fixes an issue of the CDI API.
Custom parametrized type implementation.
 
 
 
 
Base class for passivating contexts.
 
 
OpenWebBeans plugins are used to extend 'core' functionality of the injection mechanism with functionality of other frameworks.
 
 
 
 
Default implementation of the ProcessAnnotatedType.
 
Implementation of the ProcessBean.
Fired for every InjectionPoint of every Java EE component class supporting injection, including every jakarta.annotation.ManagedBean, EJB session or message-driven bean, bean, interceptor or decorator.
Implementation of the ProcessInjectionTarget.
Implementation of ProcessManagedBean.
Implementation of  ProcessObserverMethod.
Implementation of the ProcessProducerField.
Implementation of ProcessProducer.
Implementation of ProcessProducerMethod.
Implementation of ProcessSessionBean.
Default implementation of the ProcessSyntheticAnnotatedType.
 
 
Defines the producer field component implementation.
 
 
 
Concrete implementation of the AbstractOwbBean.
 
 
A Producer for producer-method beans.
Utility class to load configuration properties via a list of artibrary property files by a well defined order.
 
 
Exceptions which might happen during proxy creation.
Request context implementation.
 
 
RequestScoped literal annotation.
This is a Provider especially made for @RequestScoped beans used in web applications.
 
 
 
 
 
Deprecated.
use SecurityService instead
 
Implicit self-interceptor Bean implementation.
Bean builder for InterceptorBeans.
Wrapper to make all our Beans serializable.
This class acts as a storage for SerializableBeans.
Session context implementation.
This is a Provider especially made for @SessionScoped beans used in web applications.
RequestScoped literal annotation.
 
 
A version of the SecurityService which directly invokes the underlying Class methods instead of using a SecurityManager.
This is a special 'Set' which actually is no Collection but only contains a very single item.
Application context implementation.
This class contains a few helpers for handling @Specializes.
 
 
Default LifeCycle for a standalone application without a ServletContainer.
Manager for the StereoTypeModel instances.
Default implementation of the IStereoTypeModel contract.
a few static string utility methods
This factory creates subclasses for abstract classes.
 
 
 
 
 
 
 
 
A Set which only takes the externalForm as key instead the very expensive hashCode.
InjectionTargetFactory which validates the craeted InjectionTarget.
 
Exception that is thrown by the web beans container at the intialization time.
Web beans related constants.
This is the central point to manage the whole CDI container for a single application There is one WebBeansContext per BeanManagerImpl.
Exception that is thrown by the web beans container at the deployment time.
Exception that is thrown by the web beans container at the deployment time.
Implementation of the ErrorHandler .
 
Holds the SingletonService that tracks WebBeansContext instances
Wrapper class around the JUL logger class to include some checks before the logs are actually written.
 
There are different Web Beans Component with regard to the definition.
Contains some utility methods used in the all project.