Package org.apache.webbeans.component
Class EventBean<T>
java.lang.Object
org.apache.webbeans.component.BeanAttributesImpl<T>
org.apache.webbeans.component.AbstractOwbBean<T>
org.apache.webbeans.component.BuiltInOwbBean<jakarta.enterprise.event.Event<T>>
org.apache.webbeans.component.EventBean<T>
- All Implemented Interfaces:
jakarta.enterprise.context.spi.Contextual<jakarta.enterprise.event.Event<T>>,jakarta.enterprise.inject.spi.Bean<jakarta.enterprise.event.Event<T>>,jakarta.enterprise.inject.spi.BeanAttributes<jakarta.enterprise.event.Event<T>>,jakarta.enterprise.inject.spi.PassivationCapable,OwbBean<jakarta.enterprise.event.Event<T>>
Implicit observable bean definition.
- Version:
- $Rev$ $Date$
-
Field Summary
Fields inherited from class org.apache.webbeans.component.AbstractOwbBean
enabled, logger, passivatingId, specializedBean, webBeansContext, webBeansType -
Constructor Summary
ConstructorsConstructorDescriptionEventBean(WebBeansContext webBeansContext) Creates a new instance of event bean. -
Method Summary
Methods inherited from class org.apache.webbeans.component.BuiltInOwbBean
getProducerMethods inherited from class org.apache.webbeans.component.AbstractOwbBean
addToStringInfo, create, destroy, equals, getBeanClass, getId, getInjectionPoints, getLogger, getReturnType, getWebBeansContext, getWebBeansType, hashCode, isDependent, isEnabled, isSpecializedBean, providedId, setEnabled, setSpecializedBean, toStringMethods inherited from class org.apache.webbeans.component.BeanAttributesImpl
getName, getQualifiers, getScope, getStereotypes, getTypes, isAlternativeMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface jakarta.enterprise.inject.spi.BeanAttributes
getName, getQualifiers, getScope, getStereotypes, getTypes, isAlternative
-
Constructor Details
-
EventBean
Creates a new instance of event bean.- Parameters:
webBeansContext-
-
-
Method Details
-
isPassivationCapable
public boolean isPassivationCapable()Description copied from interface:OwbBeanTrue if passivation capable false otherwise.- Specified by:
isPassivationCapablein interfaceOwbBean<T>- Overrides:
isPassivationCapablein classAbstractOwbBean<jakarta.enterprise.event.Event<T>>- Returns:
- true if this bean is passivation capable
-
proxyableType
- Specified by:
proxyableTypein classBuiltInOwbBean<jakarta.enterprise.event.Event<T>>- Returns:
- some built in beans can be decorated, this class is the one used to generate the proxy
-