Class ExtensionBean<T>

Type Parameters:
T - type info
All Implemented Interfaces:
jakarta.enterprise.context.spi.Contextual<T>, jakarta.enterprise.inject.spi.Bean<T>, jakarta.enterprise.inject.spi.BeanAttributes<T>, jakarta.enterprise.inject.spi.PassivationCapable, OwbBean<T>

public class ExtensionBean<T> extends BuiltInOwbBean<T>
Extension service bean definition.
Version:
$Rev$ $Date$
  • Constructor Details

    • ExtensionBean

      public ExtensionBean(WebBeansContext webBeansContext, Class<T> returnType)
      Creates a new extesion bean.
      Parameters:
      returnType - return type
      webBeansContext -
  • Method Details

    • proxyableType

      public Class<?> proxyableType()
      Specified by:
      proxyableType in class BuiltInOwbBean<T>
      Returns:
      some built in beans can be decorated, this class is the one used to generate the proxy