Class InterceptorBean.MultiMethodInvocationContext

java.lang.Object
org.apache.webbeans.component.InterceptorBean.MultiMethodInvocationContext
All Implemented Interfaces:
jakarta.interceptor.InvocationContext
Enclosing class:
InterceptorBean<T>

public static class InterceptorBean.MultiMethodInvocationContext extends Object implements jakarta.interceptor.InvocationContext
An InvocationContext wraper for handling multiple interceptor methods. We will first make sure the own interceptor methods get handled and only then continue with the wrapped InvocationHandler.
  • Constructor Details

    • MultiMethodInvocationContext

      public MultiMethodInvocationContext(jakarta.interceptor.InvocationContext wrapped, jakarta.enterprise.inject.spi.InterceptionType interceptionType, Object instance, jakarta.enterprise.inject.spi.Interceptor interceptor)
  • Method Details

    • getCurrentInterceptorIdx

      public int getCurrentInterceptorIdx()
    • getWrapped

      public jakarta.interceptor.InvocationContext getWrapped()
    • proceed

      public Object proceed() throws Exception
      Specified by:
      proceed in interface jakarta.interceptor.InvocationContext
      Throws:
      Exception
    • getContextData

      public Map<String,Object> getContextData()
      Specified by:
      getContextData in interface jakarta.interceptor.InvocationContext
    • getMethod

      public Method getMethod()
      Specified by:
      getMethod in interface jakarta.interceptor.InvocationContext
    • getTarget

      public Object getTarget()
      Specified by:
      getTarget in interface jakarta.interceptor.InvocationContext
    • getTimer

      public Object getTimer()
      Specified by:
      getTimer in interface jakarta.interceptor.InvocationContext
    • getParameters

      public Object[] getParameters()
      Specified by:
      getParameters in interface jakarta.interceptor.InvocationContext
    • setParameters

      public void setParameters(Object[] parameters)
      Specified by:
      setParameters in interface jakarta.interceptor.InvocationContext
    • getConstructor

      public Constructor<?> getConstructor()
      Specified by:
      getConstructor in interface jakarta.interceptor.InvocationContext
    • getInterceptorBindings

      public Set<Annotation> getInterceptorBindings()
      Specified by:
      getInterceptorBindings in interface jakarta.interceptor.InvocationContext