Class InterceptorMetadataBean<T>

java.lang.Object
org.apache.webbeans.component.BeanAttributesImpl<T>
org.apache.webbeans.component.AbstractOwbBean<T>
org.apache.webbeans.component.BuiltInOwbBean<jakarta.enterprise.inject.spi.Interceptor<T>>
org.apache.webbeans.component.InterceptorMetadataBean<T>
All Implemented Interfaces:
jakarta.enterprise.context.spi.Contextual<jakarta.enterprise.inject.spi.Interceptor<T>>, jakarta.enterprise.inject.spi.Bean<jakarta.enterprise.inject.spi.Interceptor<T>>, jakarta.enterprise.inject.spi.BeanAttributes<jakarta.enterprise.inject.spi.Interceptor<T>>, jakarta.enterprise.inject.spi.PassivationCapable, OwbBean<jakarta.enterprise.inject.spi.Interceptor<T>>

public class InterceptorMetadataBean<T> extends BuiltInOwbBean<jakarta.enterprise.inject.spi.Interceptor<T>>
Implicit metadata bean definition.
Version:
$Rev: 1493478 $ $Date: 2013-06-16 11:19:42 +0200 (So, 16 Jun 2013) $
  • Constructor Details

    • InterceptorMetadataBean

      public InterceptorMetadataBean(WebBeansContext webBeansContext)
  • Method Details

    • isPassivationCapable

      public boolean isPassivationCapable()
      Description copied from interface: OwbBean
      True if passivation capable false otherwise.
      Specified by:
      isPassivationCapable in interface OwbBean<T>
      Overrides:
      isPassivationCapable in class AbstractOwbBean<jakarta.enterprise.inject.spi.Interceptor<T>>
      Returns:
      true if this bean is passivation capable
    • proxyableType

      public Class<?> proxyableType()
      Specified by:
      proxyableType in class BuiltInOwbBean<jakarta.enterprise.inject.spi.Interceptor<T>>
      Returns:
      some built in beans can be decorated, this class is the one used to generate the proxy