Class DefaultAnnotation

java.lang.Object
org.apache.webbeans.config.DefaultAnnotation
All Implemented Interfaces:
Annotation, InvocationHandler

public final class DefaultAnnotation extends Object implements InvocationHandler, Annotation
A small helper class to create a Annotation instance of the given annotation class via Proxy. The annotation literal gets filled with the default values. TODO implement class caching!