Package org.apache.webbeans.config
Class DeploymentValidationService
java.lang.Object
org.apache.webbeans.config.DeploymentValidationService
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescription<T> voidvalidatePassivationCapable(OwbBean<T> bean) If bean is passivation capable, it validate all of its dependencies.jakarta.enterprise.inject.UnproxyableResolutionExceptionvalidateProxyable(OwbBean<?> bean, boolean ignoreFinalMethods) Checks the unproxyable condition.
-
Constructor Details
-
DeploymentValidationService
-
-
Method Details
-
validateProxyable
public jakarta.enterprise.inject.UnproxyableResolutionException validateProxyable(OwbBean<?> bean, boolean ignoreFinalMethods) Checks the unproxyable condition.- Returns:
- exception TCKs validate at runtime
- Throws:
WebBeansConfigurationException- if bean is not proxied by the container
-
validatePassivationCapable
If bean is passivation capable, it validate all of its dependencies.- Throws:
WebBeansConfigurationException- if not satisfy passivation dependencies
-