Class WebBeansContext

java.lang.Object
org.apache.webbeans.config.WebBeansContext

public class WebBeansContext extends Object
This is the central point to manage the whole CDI container for a single application There is one WebBeansContext per BeanManagerImpl.
Version:
$Rev$ $Date$
  • Constructor Details

    • WebBeansContext

      public WebBeansContext()
    • WebBeansContext

      public WebBeansContext(Map<Class<?>,Object> initialServices, Properties properties)
  • Method Details

    • getBeanManagerBean

      public jakarta.enterprise.inject.spi.Bean<jakarta.enterprise.inject.spi.BeanManager> getBeanManagerBean()
    • getInjectableBeanManager

      public InjectableBeanManager getInjectableBeanManager()
    • getInstance

      public static WebBeansContext getInstance()
    • currentInstance

      public static WebBeansContext currentInstance()
      Method to be used when static use is truely unavoidable, such as serialization Ideally this method would never lazily create a WebBeansContext and as we don't want to do any deployment of new apps during deserialization, we want to rehydrate objects from an existing WebBeansContext which should be the active context. This method could throw a runtime exception if no instance currently exists.
      Returns:
    • getService

      public <T> T getService(Class<T> clazz)
    • registerService

      public <T> void registerService(Class<T> clazz, T t)
    • getInterceptorUtil

      public InterceptorUtil getInterceptorUtil()
    • getInjectionPointFactory

      public InjectionPointFactory getInjectionPointFactory()
    • getWebBeansUtil

      public WebBeansUtil getWebBeansUtil()
    • getAnnotationManager

      public AnnotationManager getAnnotationManager()
    • getConversationManager

      public ConversationManager getConversationManager()
    • getOpenWebBeansConfiguration

      public OpenWebBeansConfiguration getOpenWebBeansConfiguration()
    • getAnnotatedElementFactory

      public AnnotatedElementFactory getAnnotatedElementFactory()
    • getBeanManagerImpl

      public BeanManagerImpl getBeanManagerImpl()
    • getSerializableBeanVault

      public SerializableBeanVault getSerializableBeanVault()
    • getCreationalContextFactory

      public CreationalContextFactory getCreationalContextFactory()
    • getDecoratorsManager

      public DecoratorsManager getDecoratorsManager()
    • getStereoTypeManager

      public StereoTypeManager getStereoTypeManager()
    • getAlternativesManager

      public AlternativesManager getAlternativesManager()
    • getInterceptorsManager

      public InterceptorsManager getInterceptorsManager()
    • getInterceptorResolutionService

      public InterceptorResolutionService getInterceptorResolutionService()
    • getPluginLoader

      public PluginLoader getPluginLoader()
    • getExtensionLoader

      public ExtensionLoader getExtensionLoader()
    • getInterceptorDecoratorProxyFactory

      public InterceptorDecoratorProxyFactory getInterceptorDecoratorProxyFactory()
    • getNormalScopeProxyFactory

      public NormalScopeProxyFactory getNormalScopeProxyFactory()
    • getSubclassProxyFactory

      public SubclassProxyFactory getSubclassProxyFactory()
    • getTransactionService

      public org.apache.webbeans.spi.TransactionService getTransactionService()
    • getScannerService

      public org.apache.webbeans.spi.ScannerService getScannerService()
    • getContextsService

      public org.apache.webbeans.spi.ContextsService getContextsService()
    • getSecurityService

      public org.apache.webbeans.spi.SecurityService getSecurityService()
    • getBeanArchiveService

      public org.apache.webbeans.spi.BeanArchiveService getBeanArchiveService()
    • getNotificationManager

      public NotificationManager getNotificationManager()
    • getConversationService

      public org.apache.webbeans.spi.ConversationService getConversationService()
    • get

      public <T> T get(Class<T> clazz)
    • clear

      public void clear()
      Clear and destroy the whole WebBeansContext. This will also properly destroy all SPI services
    • getLoaderService

      public org.apache.webbeans.spi.LoaderService getLoaderService()
    • getDeploymentValidationService

      public DeploymentValidationService getDeploymentValidationService()
    • getApplicationBoundaryService

      public org.apache.webbeans.spi.ApplicationBoundaryService getApplicationBoundaryService()
    • findMissingAnnotatedType

      public boolean findMissingAnnotatedType(Class<?> missing)