Class ExternalScope

java.lang.Object
org.apache.webbeans.container.ExternalScope

public class ExternalScope extends Object
A wrapper for an external scope which can be added by BeforeBeanDiscovery.addScope(Class, boolean, boolean).
  • Constructor Details

    • ExternalScope

      public ExternalScope(Class<? extends Annotation> scope, boolean normal, boolean passivating)
  • Method Details

    • getScope

      public Class<? extends Annotation> getScope()
    • isNormal

      public boolean isNormal()
    • isPassivating

      public boolean isPassivating()
    • getScopeAnnotation

      public Annotation getScopeAnnotation()
      Returns:
      an instance of the annotation class we got set in BeforeBeanDiscovery.addScope(Class, boolean, boolean)