Package org.apache.webbeans.context
Class AbstractContextsService
java.lang.Object
org.apache.webbeans.context.AbstractContextsService
- All Implemented Interfaces:
org.apache.webbeans.spi.ContextsService
- Direct Known Subclasses:
BaseSeContextsService
public abstract class AbstractContextsService
extends Object
implements org.apache.webbeans.spi.ContextsService
-
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Booleanprotected booleanprotected final WebBeansContext -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidvoiddestroyOutdatedConversations(ConversationContext currentConversationContext) Destroy inactive (timed out) conversations.voidOWB-1074: enableConversationScopedinfrastructure when the deployment defines at least one enabled bean with that scope (fast bean scan).voidendContext(Class<? extends Annotation> scopeType, Object endParameters) jakarta.enterprise.context.spi.ContextgetCurrentContext(Class<? extends Annotation> scopeType) jakarta.enterprise.context.spi.ContextgetCurrentContext(Class<? extends Annotation> scopeType, boolean createIfNotExists) voidbooleanvoidvoidsetSupportConversations(boolean supportConversations) protected booleanvoidstartContext(Class<? extends Annotation> scopeType, Object startParameter)
-
Field Details
-
webBeansContext
-
supportsConversation
protected boolean supportsConversation -
fireRequestLifecycleEvents
-
-
Constructor Details
-
AbstractContextsService
-
-
Method Details
-
detectConversationSupport
OWB-1074: enableConversationScopedinfrastructure when the deployment defines at least one enabled bean with that scope (fast bean scan). Same rule in SE and servlet (WebContextsService) modes. -
destroy
- Specified by:
destroyin interfaceorg.apache.webbeans.spi.ContextsService
-
endContext
- Specified by:
endContextin interfaceorg.apache.webbeans.spi.ContextsService
-
getCurrentContext
public jakarta.enterprise.context.spi.Context getCurrentContext(Class<? extends Annotation> scopeType) - Specified by:
getCurrentContextin interfaceorg.apache.webbeans.spi.ContextsService
-
getCurrentContext
public jakarta.enterprise.context.spi.Context getCurrentContext(Class<? extends Annotation> scopeType, boolean createIfNotExists) - Specified by:
getCurrentContextin interfaceorg.apache.webbeans.spi.ContextsService
-
init
- Specified by:
initin interfaceorg.apache.webbeans.spi.ContextsService
-
startContext
public void startContext(Class<? extends Annotation> scopeType, Object startParameter) throws jakarta.enterprise.context.ContextException - Specified by:
startContextin interfaceorg.apache.webbeans.spi.ContextsService- Throws:
jakarta.enterprise.context.ContextException
-
removeThreadLocals
public void removeThreadLocals()- Specified by:
removeThreadLocalsin interfaceorg.apache.webbeans.spi.ContextsService
-
setSupportConversations
public void setSupportConversations(boolean supportConversations) - Specified by:
setSupportConversationsin interfaceorg.apache.webbeans.spi.ContextsService
-
destroyOutdatedConversations
Destroy inactive (timed out) conversations. -
isSupportsConversation
public boolean isSupportsConversation() -
shouldFireRequestLifecycleEvents
protected boolean shouldFireRequestLifecycleEvents()
-