Class ApplicationContext

java.lang.Object
org.apache.webbeans.context.AbstractContext
org.apache.webbeans.context.ApplicationContext
All Implemented Interfaces:
jakarta.enterprise.context.spi.AlterableContext, jakarta.enterprise.context.spi.Context, Serializable

public class ApplicationContext extends AbstractContext
Application context implementation.
See Also:
  • Constructor Details

    • ApplicationContext

      public ApplicationContext()
  • Method Details

    • setComponentInstanceMap

      public void setComponentInstanceMap()
      Description copied from class: AbstractContext
      Specified by:
      setComponentInstanceMap in class AbstractContext
    • destroy

      public void destroy()
      By default a Context destroys all it's Contextual Instances. But for the ApplicationContext we only need to destroy custom beans and _not_ Extensions and internal beans
      Overrides:
      destroy in class AbstractContext
    • destroySystemBeans

      public void destroySystemBeans()
      This method should only get called at container shutdown. It will destroy the Extensions as well
    • isDestroyed

      public boolean isDestroyed()
      Returns: