|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||
java.lang.Objectorg.apache.webbeans.context.ContextFactory
public final class ContextFactory
JSR-299 based standard context related operations.
| Constructor Summary | |
|---|---|
ContextFactory(WebBeansContext webBeansContext)
Deprecated. |
|
| Method Summary | |
|---|---|
void |
destroyApplicationContext(Object parameter)
Deprecated. Destroys the application context and all of its components at the end of the application. |
void |
destroyConversationContext()
Deprecated. |
void |
destroyRequestContext(Object request)
Deprecated. |
void |
destroySessionContext(Object session)
Deprecated. |
void |
destroySingletonContext(Object parameter)
Deprecated. |
Context |
getCustomContext(Context context)
Deprecated. |
Context |
getStandardContext(Class<? extends Annotation> scopeType)
Deprecated. Gets the standard context with given scope type. |
void |
initApplicationContext(Object parameter)
Deprecated. |
void |
initConversationContext(Object context)
Deprecated. |
void |
initRequestContext(Object request)
Deprecated. |
void |
initSessionContext(Object session)
Deprecated. |
void |
initSingletonContext(Object parameter)
Deprecated. |
| Methods inherited from class java.lang.Object |
|---|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
| Constructor Detail |
|---|
public ContextFactory(WebBeansContext webBeansContext)
| Method Detail |
|---|
public void initRequestContext(Object request)
public Context getCustomContext(Context context)
public void destroyRequestContext(Object request)
public void initSessionContext(Object session)
public void destroySessionContext(Object session)
public void initApplicationContext(Object parameter)
public void destroyApplicationContext(Object parameter)
parameter - parameter objectpublic void initSingletonContext(Object parameter)
public void destroySingletonContext(Object parameter)
public void initConversationContext(Object context)
public void destroyConversationContext()
public Context getStandardContext(Class<? extends Annotation> scopeType)
null if no standard context exists for the given scopeType
|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||