org.apache.webbeans.context
Class ConversationContext

java.lang.Object
  extended by org.apache.webbeans.context.AbstractContext
      extended by org.apache.webbeans.context.PassivatingContext
          extended by org.apache.webbeans.context.ConversationContext
All Implemented Interfaces:
Externalizable, Serializable, javax.enterprise.context.spi.AlterableContext, javax.enterprise.context.spi.Context

public class ConversationContext
extends PassivatingContext
implements Serializable

Conversation context implementation. This reflects THE current Conversation (there can only be one active at a time for a thread). It should not be confused with the Map of conversationId -> Conversation which we internally store in the SessionContext.

See Also:
Serialized Form

Field Summary
 
Fields inherited from class org.apache.webbeans.context.AbstractContext
active, componentInstanceMap, scopeType
 
Constructor Summary
ConversationContext()
           
ConversationContext(WebBeansContext webBeansContext)
          Constructor
 
Method Summary
 ConversationImpl getConversation()
           
 void setComponentInstanceMap()
          
 
Methods inherited from class org.apache.webbeans.context.PassivatingContext
readExternal, writeExternal
 
Methods inherited from class org.apache.webbeans.context.AbstractContext
checkActive, destroy, destroy, destroyInstance, get, get, getInstance, getScope, isActive, setActive
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 

Constructor Detail

ConversationContext

public ConversationContext()

ConversationContext

public ConversationContext(WebBeansContext webBeansContext)
Constructor

Method Detail

setComponentInstanceMap

public void setComponentInstanceMap()
Description copied from class: AbstractContext

Specified by:
setComponentInstanceMap in class AbstractContext

getConversation

public ConversationImpl getConversation()


Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.