Class DependentContext

java.lang.Object
org.apache.webbeans.context.AbstractContext
org.apache.webbeans.context.DependentContext
All Implemented Interfaces:
jakarta.enterprise.context.spi.AlterableContext, jakarta.enterprise.context.spi.Context, Serializable

public class DependentContext extends AbstractContext
Defines the component Dependent context.

Each web beans component has a dependent context, that saves its dependent objects. Dependent context is destroyed at the end of the component destruction or its dependent objects are destroyed by the container at any time that the dependent object is no longer alive.

Dependent context is always active.

Version:
$Rev$ $Date$
See Also:
  • Constructor Details

    • DependentContext

      public DependentContext()
      Creats a new instance of dependent context.
  • Method Details

    • getInstance

      protected <T> T getInstance(jakarta.enterprise.context.spi.Contextual<T> component, jakarta.enterprise.context.spi.CreationalContext<T> creationalContext)
      Overrides:
      getInstance in class AbstractContext
    • setComponentInstanceMap

      public void setComponentInstanceMap()
      Specified by:
      setComponentInstanceMap in class AbstractContext
    • get

      public <T> T get(jakarta.enterprise.context.spi.Contextual<T> component)
      Specified by:
      get in interface jakarta.enterprise.context.spi.Context
      Overrides:
      get in class AbstractContext