org.apache.webbeans.corespi
Class DefaultSingletonService

java.lang.Object
  extended by org.apache.webbeans.corespi.DefaultSingletonService
All Implemented Interfaces:
SingletonService<WebBeansContext>

public class DefaultSingletonService
extends Object
implements SingletonService<WebBeansContext>


Constructor Summary
DefaultSingletonService()
           
 
Method Summary
 void clear(Object classLoader)
          
 void clearInstances(ClassLoader classLoader)
          Clear all deployment instances when the application is undeployed.
 WebBeansContext get(Object key)
          Gets singleton instance for deployment.
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 

Constructor Detail

DefaultSingletonService

public DefaultSingletonService()
Method Detail

get

public WebBeansContext get(Object key)
Gets singleton instance for deployment.

Specified by:
get in interface SingletonService<WebBeansContext>
Returns:
signelton instance for this deployment

clearInstances

public void clearInstances(ClassLoader classLoader)
Clear all deployment instances when the application is undeployed.

Parameters:
classLoader - of the deployment

clear

public void clear(Object classLoader)

Specified by:
clear in interface SingletonService<WebBeansContext>


Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.