org.apache.webbeans.event
Interface EventMetadata

All Known Implementing Classes:
EventMetadataImpl

public interface EventMetadata

This is a preview to CDI 1.1 when we implement CDI 1.1 this interface can be removed


Method Summary
 InjectionPoint getInjectionPoint()
          Get the InjectionPoint from which the event fired, or null if it was fired from {@link javax.enterprise.inject.spi.BeanManager#fireEvent(Object, Annotation
 Set<Annotation> getQualifiers()
          Get the qualifiers for which event payload was fired.
 Type getType()
          Returns the resolved event Type.
 

Method Detail

getQualifiers

Set<Annotation> getQualifiers()
Get the qualifiers for which event payload was fired.


getInjectionPoint

InjectionPoint getInjectionPoint()
Get the InjectionPoint from which the event fired, or null if it was fired from BeanManager.fireEvent(Object, Annotation...);


getType

Type getType()
Returns the resolved event Type.



Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.