org.apache.webbeans.event
Class EventMetadataImpl

java.lang.Object
  extended by org.apache.webbeans.event.EventMetadataImpl
All Implemented Interfaces:
EventMetadata

public class EventMetadataImpl
extends Object
implements EventMetadata


Constructor Summary
EventMetadataImpl(Type type, InjectionPoint injectionPoint, Annotation... qualifiers)
           
 
Method Summary
 InjectionPoint getInjectionPoint()
          Get the InjectionPoint from which the event fired, or null if it was fired from {@link javax.enterprise.inject.spi.BeanManager#fireEvent(Object, Annotation
 Set<Annotation> getQualifiers()
          Get the qualifiers for which event payload was fired.
 Type getType()
          Returns the resolved event Type.
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 

Constructor Detail

EventMetadataImpl

public EventMetadataImpl(Type type,
                         InjectionPoint injectionPoint,
                         Annotation... qualifiers)
Method Detail

getType

public Type getType()
Description copied from interface: EventMetadata
Returns the resolved event Type.

Specified by:
getType in interface EventMetadata

getInjectionPoint

public InjectionPoint getInjectionPoint()
Description copied from interface: EventMetadata
Get the InjectionPoint from which the event fired, or null if it was fired from BeanManager.fireEvent(Object, Annotation...);

Specified by:
getInjectionPoint in interface EventMetadata

getQualifiers

public Set<Annotation> getQualifiers()
Description copied from interface: EventMetadata
Get the qualifiers for which event payload was fired.

Specified by:
getQualifiers in interface EventMetadata


Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.