Uses of Class
org.apache.webbeans.exception.ProxyGenerationException

Packages that use ProxyGenerationException
org.apache.webbeans.proxy   
 

Uses of ProxyGenerationException in org.apache.webbeans.proxy
 

Methods in org.apache.webbeans.proxy that throw ProxyGenerationException
protected  void AbstractProxyFactory.createArrayDefinition(org.apache.xbean.asm5.MethodVisitor mv, int size, Class<?> type)
          pushes an array of the specified size to the method visitor.
protected  void SubclassProxyFactory.createConstructor(org.apache.xbean.asm5.ClassWriter cw, String proxyClassFileName, Class<?> classToProxy, String classFileName, Constructor<?> constructor)
           
protected  void NormalScopeProxyFactory.createConstructor(org.apache.xbean.asm5.ClassWriter cw, String proxyClassFileName, Class<?> classToProxy, String classFileName, Constructor<?> ignored)
           
protected  void InterceptorDecoratorProxyFactory.createConstructor(org.apache.xbean.asm5.ClassWriter cw, String proxyClassFileName, Class<?> classToProxy, String classFileName, Constructor<?> ignored)
          Each of our interceptor/decorator proxies has exactly 1 constructor which invokes the super ct + sets the delegation field.
protected abstract  void AbstractProxyFactory.createConstructor(org.apache.xbean.asm5.ClassWriter cw, String proxyClassFileName, Class<?> classToProxy, String classFileName, Constructor<?> injectConstructor)
          Each of our interceptor/decorator proxies has exactly 1 constructor which invokes the super ct + sets the delegation field.
<T> Class<T>
InterceptorDecoratorProxyFactory.createProxyClass(javax.enterprise.inject.spi.Bean<T> bean, ClassLoader classLoader, Class<T> classToProxy, Method[] interceptedMethods, Method[] nonInterceptedMethods)
          Create a decorator and interceptor proxy for the given type.
<T> Class<T>
NormalScopeProxyFactory.createProxyClass(ClassLoader classLoader, Class<T> classToProxy)
           
protected
<T> Class<T>
AbstractProxyFactory.createProxyClass(ClassLoader classLoader, String proxyClassName, Class<T> classToProxy, Method[] interceptedMethods, Method[] nonInterceptedMethods)
           
protected
<T> Class<T>
AbstractProxyFactory.createProxyClass(ClassLoader classLoader, String proxyClassName, Class<T> classToProxy, Method[] interceptedMethods, Method[] nonInterceptedMethods, Constructor<T> constructor)
           
<T> T
InterceptorDecoratorProxyFactory.createProxyInstance(Class<? extends T> proxyClass, T instance, InterceptorHandler interceptorDecoratorStack)
           
<T> T
NormalScopeProxyFactory.createProxyInstance(Class<T> proxyClass, javax.inject.Provider provider)
           
<T> Class<T>
SubclassProxyFactory.createSubClass(ClassLoader classLoader, javax.enterprise.inject.spi.AnnotatedType<T> annotatedType)
           
protected  void SubclassProxyFactory.delegateInterceptedMethods(ClassLoader classLoader, org.apache.xbean.asm5.ClassWriter cw, String proxyClassFileName, Class<?> classToProxy, Method[] interceptedMethods)
           
protected  void NormalScopeProxyFactory.delegateInterceptedMethods(ClassLoader classLoader, org.apache.xbean.asm5.ClassWriter cw, String proxyClassFileName, Class<?> classToProxy, Method[] interceptedMethods)
          In the NormalScope proxying case this is used for all the protected methods as they need to get invoked via reflection.
protected  void InterceptorDecoratorProxyFactory.delegateInterceptedMethods(ClassLoader classLoader, org.apache.xbean.asm5.ClassWriter cw, String proxyClassFileName, Class<?> classToProxy, Method[] interceptedMethods)
           
protected abstract  void AbstractProxyFactory.delegateInterceptedMethods(ClassLoader classLoader, org.apache.xbean.asm5.ClassWriter cw, String proxyClassFileName, Class<?> classToProxy, Method[] interceptedMethods)
          generate the bytecode for invoking all intercepted methods
protected  void SubclassProxyFactory.delegateNonInterceptedMethods(ClassLoader classLoader, org.apache.xbean.asm5.ClassWriter cw, String proxyClassFileName, Class<?> classToProxy, Method[] noninterceptedMethods)
           
protected  void NormalScopeProxyFactory.delegateNonInterceptedMethods(ClassLoader classLoader, org.apache.xbean.asm5.ClassWriter cw, String proxyClassFileName, Class<?> classToProxy, Method[] noninterceptedMethods)
           
protected abstract  void AbstractProxyFactory.delegateNonInterceptedMethods(ClassLoader classLoader, org.apache.xbean.asm5.ClassWriter cw, String proxyClassFileName, Class<?> classToProxy, Method[] noninterceptedMethods)
          generate the bytecode for invoking all non-intercepted methods
 



Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.