Uses of Class
org.apache.webbeans.exception.WebBeansConfigurationException
Packages that use WebBeansConfigurationException
-
Uses of WebBeansConfigurationException in org.apache.webbeans.config
Methods in org.apache.webbeans.config that throw WebBeansConfigurationExceptionModifier and TypeMethodDescriptionstatic booleanEJBWebBeansConfigurator.isSessionBean(Class<?> clazz, WebBeansContext webBeansContext) Returns true if given class is an deployed ejb bean class, false otherwise.voidOpenWebBeansConfiguration.parseConfiguration()(re)read the configuration from the resources in the classpath. -
Uses of WebBeansConfigurationException in org.apache.webbeans.plugins
Methods in org.apache.webbeans.plugins that throw WebBeansConfigurationExceptionModifier and TypeMethodDescriptionvoidPluginLoader.shutDown()Tell all the plugins to free up all locked resources.voidPluginLoader.startUp()load and startup all registered plugins.static voidPluginLoader.throwsException(Exception e) -
Uses of WebBeansConfigurationException in org.apache.webbeans.util
Methods in org.apache.webbeans.util that throw WebBeansConfigurationExceptionModifier and TypeMethodDescription<X> voidWebBeansUtil.checkManagedBeanCondition(jakarta.enterprise.inject.spi.AnnotatedType<X> type) Checks the implementation class for checking conditions.voidWebBeansUtil.checkManagedBeanCondition(Class<?> clazz) booleanWebBeansUtil.isConstructorOk(jakarta.enterprise.inject.spi.AnnotatedType<?> annotatedType) Check that simple web beans class has compatible constructor.