Package org.apache.webbeans.inject
Class AbstractInjectable<T>
java.lang.Object
org.apache.webbeans.inject.AbstractInjectable<T>
- Direct Known Subclasses:
InjectableConstructor,InjectableField,InjectableMethod
Abstract implementation of all components which are injectable.
Do actual injection via inject(InjectionPoint)
-
Field Summary
FieldsModifier and TypeFieldDescriptionprotected final CreationalContextImpl<?>protected jakarta.enterprise.inject.spi.Producer<?>protected CreationalContextImpl<?> -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedAbstractInjectable(jakarta.enterprise.inject.spi.Producer<?> owner, CreationalContextImpl<?> creationalContext) -
Method Summary
Modifier and TypeMethodDescriptionprotected static List<jakarta.enterprise.inject.spi.InjectionPoint>createInjectionPoints(jakarta.enterprise.inject.spi.Producer<?> owner, Member member) protected jakarta.enterprise.context.spi.Contextual<?>getBean()protected List<jakarta.enterprise.inject.spi.InjectionPoint>getInjectionPoints(Member member) Returns injection points related with given member type of the bean.protected WebBeansContextinject(jakarta.enterprise.inject.spi.InjectionPoint injectionPoint) Gets the injected bean instance in its scoped context.
-
Field Details
-
owner
protected jakarta.enterprise.inject.spi.Producer<?> owner -
creationalContext
-
transientCreationalContext
-
-
Constructor Details
-
AbstractInjectable
protected AbstractInjectable(jakarta.enterprise.inject.spi.Producer<?> owner, CreationalContextImpl<?> creationalContext)
-
-
Method Details
-
inject
Gets the injected bean instance in its scoped context.- Parameters:
injectionPoint- injection point definition- Returns:
- current bean instance in the resolved bean scope
-
getBean
protected jakarta.enterprise.context.spi.Contextual<?> getBean() -
getWebBeansContext
-
getInjectionPoints
Returns injection points related with given member type of the bean.- Parameters:
member- java member- Returns:
- injection points related with given member type
-
createInjectionPoints
-