Package org.apache.webbeans.intercept
Class DefaultInterceptorHandler<T>
java.lang.Object
org.apache.webbeans.intercept.DefaultInterceptorHandler<T>
- All Implemented Interfaces:
Externalizable,Serializable,InterceptorHandler
public class DefaultInterceptorHandler<T>
extends Object
implements InterceptorHandler, Externalizable
- See Also:
-
Constructor Summary
ConstructorsConstructorDescriptionDefaultInterceptorHandler(T target, T delegate, Map<Method, List<jakarta.enterprise.inject.spi.Interceptor<?>>> interceptors, Map<jakarta.enterprise.inject.spi.Interceptor<?>, ?> instances, String beanPassivationId) InterceptorHandler wich gets used in our InjectionTargets which support interceptors and decoratorsDefaultInterceptorHandler(T target, T delegate, Map<Method, List<jakarta.enterprise.inject.spi.Interceptor<?>>> interceptors, Map<Method, Set<Annotation>> methodInterceptorBindings, Map<jakarta.enterprise.inject.spi.Interceptor<?>, ?> instances, String beanPassivationId) -
Method Summary
Modifier and TypeMethodDescriptionMap<jakarta.enterprise.inject.spi.Interceptor<?>,?> This method will get called whenever the proxy of the intercepted instance will get invoked.voidvoid
-
Constructor Details
-
DefaultInterceptorHandler
public DefaultInterceptorHandler(T target, T delegate, Map<Method, List<jakarta.enterprise.inject.spi.Interceptor<?>>> interceptors, Map<jakarta.enterprise.inject.spi.Interceptor<?>, ?> instances, String beanPassivationId) InterceptorHandler wich gets used in our InjectionTargets which support interceptors and decorators- Parameters:
target- the decorated and intercepted instance. Needed for delivering Events to private methods, etc.delegate- the outermost Decorator or the intercepted instanceinterceptors- Map with all active interceptors for each method.instances- the Interceptor instancesbeanPassivationId- passivationId if a Bean isPassivationCapable
-
DefaultInterceptorHandler
-
DefaultInterceptorHandler
public DefaultInterceptorHandler()
-
-
Method Details
-
getTarget
-
getDelegate
-
getInstances
-
getInterceptors
-
invoke
Description copied from interface:InterceptorHandlerThis method will get called whenever the proxy of the intercepted instance will get invoked.- Specified by:
invokein interfaceInterceptorHandler- Parameters:
method- Method which should get invokedparameters- original invocation parameters- Returns:
- the return value of the intercepted methos
-
writeExternal
- Specified by:
writeExternalin interfaceExternalizable- Throws:
IOException
-
readExternal
- Specified by:
readExternalin interfaceExternalizable- Throws:
IOExceptionClassNotFoundException
-