Package org.apache.webbeans.intercept
Class InterceptorResolutionService
java.lang.Object
org.apache.webbeans.intercept.InterceptorResolutionService
Class to calculate interceptor resolution information.
It also handles the proxy caching and applying.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classstatic information about interceptors and decorators for a single bean.static classWe track per method which Interceptors to invokestatic final classClass-scoped CDI interceptors and their effective interceptor bindings.static classstatic final classBusiness-method interceptors plus per-method CDIInvocationContextbindings. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncalculateInterceptorInfo(Set<Type> beanTypes, Set<Annotation> qualifiers, jakarta.enterprise.inject.spi.AnnotatedType<T> annotatedType, boolean failOnFinal) createInterceptorInstances(InterceptorResolutionService.BeanInterceptorInfo interceptorInfo, CreationalContextImpl<T> creationalContextImpl) CDI interceptor bindings per business method forInvocationContext.getInterceptorBindings().createMethodInterceptors(InterceptorResolutionService.BeanInterceptorInfo interceptorInfo) <T> TcreateProxiedInstance(T instance, CreationalContextImpl<T> creationalContextImpl, jakarta.enterprise.context.spi.CreationalContext<T> creationalContext, InterceptorResolutionService.BeanInterceptorInfo interceptorInfo, Class<? extends T> proxyClass, InterceptorResolutionService.MethodInterceptionPlan methodPlan, String passivationId, Map<jakarta.enterprise.inject.spi.Interceptor<?>, Object> interceptorInstances, Function<CreationalContextImpl<?>, Boolean> isDelegateInjection, BiFunction<T, List<jakarta.enterprise.inject.spi.Decorator<?>>, List<jakarta.enterprise.inject.spi.Decorator<?>>> filterDecorators)
-
Constructor Details
-
InterceptorResolutionService
-
-
Method Details
-
calculateInterceptorInfo
public <T> InterceptorResolutionService.BeanInterceptorInfo calculateInterceptorInfo(Set<Type> beanTypes, Set<Annotation> qualifiers, jakarta.enterprise.inject.spi.AnnotatedType<T> annotatedType, boolean failOnFinal) -
createMethodInterceptors
public Map<Method,List<jakarta.enterprise.inject.spi.Interceptor<?>>> createMethodInterceptors(InterceptorResolutionService.BeanInterceptorInfo interceptorInfo) -
createMethodInterceptorBindings
public Map<Method,Set<Annotation>> createMethodInterceptorBindings(InterceptorResolutionService.BeanInterceptorInfo interceptorInfo) CDI interceptor bindings per business method forInvocationContext.getInterceptorBindings(). -
createInterceptorInstances
public <T> Map<jakarta.enterprise.inject.spi.Interceptor<?>,Object> createInterceptorInstances(InterceptorResolutionService.BeanInterceptorInfo interceptorInfo, CreationalContextImpl<T> creationalContextImpl) -
createProxiedInstance
public <T> T createProxiedInstance(T instance, CreationalContextImpl<T> creationalContextImpl, jakarta.enterprise.context.spi.CreationalContext<T> creationalContext, InterceptorResolutionService.BeanInterceptorInfo interceptorInfo, Class<? extends T> proxyClass, InterceptorResolutionService.MethodInterceptionPlan methodPlan, String passivationId, Map<jakarta.enterprise.inject.spi.Interceptor<?>, Object> interceptorInstances, Function<CreationalContextImpl<?>, Boolean> isDelegateInjection, BiFunction<T, List<jakarta.enterprise.inject.spi.Decorator<?>>, List<jakarta.enterprise.inject.spi.Decorator<?>>> filterDecorators)
-