Class InterceptorResolutionService.BusinessMethodInterceptorInfo

java.lang.Object
org.apache.webbeans.intercept.InterceptorResolutionService.BusinessMethodInterceptorInfo
Enclosing class:
InterceptorResolutionService

public static class InterceptorResolutionService.BusinessMethodInterceptorInfo extends Object
We track per method which Interceptors to invoke
  • Constructor Details

    • BusinessMethodInterceptorInfo

      public BusinessMethodInterceptorInfo()
  • Method Details

    • getEjbInterceptors

      public jakarta.enterprise.inject.spi.Interceptor<?>[] getEjbInterceptors()
      The (sorted) EJB-style (Interceptors) Interceptor Beans for a specific method or null if no Interceptor exists for this method. They must be called before the cdiInterceptors!
    • getCdiInterceptors

      public jakarta.enterprise.inject.spi.Interceptor<?>[] getCdiInterceptors()
      The (sorted) CDI Interceptor Beans for a specific method or null if no Interceptor exists for this method.
    • getCdiInterceptorBindings

      public Set<Annotation> getCdiInterceptorBindings()
    • setCdiInterceptorBindings

      public void setCdiInterceptorBindings(Set<Annotation> bindings)
    • getMethodDecorators

      public LinkedHashMap<jakarta.enterprise.inject.spi.Decorator<?>,Method> getMethodDecorators()
      The (sorted) Decorator Beans for a specific method or null if no Decorator exists for this method. This Map is sorted! Key: the Decorator Bean Value: the decorating method from the decorator instance
    • setCdiInterceptors

      public void setCdiInterceptors(List<jakarta.enterprise.inject.spi.Interceptor<?>> cdiInterceptors)
    • setMethodDecorators

      public void setMethodDecorators(LinkedHashMap<jakarta.enterprise.inject.spi.Decorator<?>,Method> methodDecorators)
    • setEjbInterceptors

      public void setEjbInterceptors(List<jakarta.enterprise.inject.spi.Interceptor<?>> ejbInterceptors)
    • isEmpty

      public boolean isEmpty()
      Determine if any interceptor information has been set at all.