Package org.apache.webbeans.intercept
package org.apache.webbeans.intercept
-
ClassesClassDescriptionThis is a
Providerespecially made for @ApplicationScoped beans.InterceptorHandler which handles all the Decorators on the InjectionTarget.InvocationContext for business method interceptorsClass to calculate interceptor resolution information.static information about interceptors and decorators for a single bean.We track per method which Interceptors to invokeClass-scoped CDI interceptors and their effective interceptor bindings.Business-method interceptors plus per-method CDIInvocationContextbindings.This class keeps all the enabled interceptor classes information of a certain BeanManager.InvocationContext for lifecycle methods like @PostConstruct, etc.A Provider which handles all NormalScoped proxying.This is aProviderespecially made for @RequestScoped beans used in web applications.This is aProviderespecially made for @SessionScoped beans used in web applications.