Class PluginLoader

java.lang.Object
org.apache.webbeans.plugins.PluginLoader

public class PluginLoader extends Object

OpenWebBeans plugins are used to extend 'core' functionality of the injection mechanism with functionality of other frameworks.

Core functionality are all parts which are available in a standard JDK-1.5 SE runtime. Extended functionality are things like JPA, JSF, EJB etc.

The plugin mechanism is based on the ServiceProvider functionality. A jar containing an OWB plugin has to expose itself in the file META-INF/services/org.apache.webbeans.plugins.OpenWebBeansPlugin

  • Constructor Details

    • PluginLoader

      public PluginLoader()
  • Method Details

    • startUp

      public void startUp() throws WebBeansConfigurationException
      load and startup all registered plugins. This must be called once the WebApplication is started.
      Throws:
      WebBeansConfigurationException
    • throwsException

      public static void throwsException(Exception e) throws WebBeansConfigurationException
      Throws:
      WebBeansConfigurationException
    • shutDown

      public void shutDown() throws WebBeansConfigurationException
      Tell all the plugins to free up all locked resources. This must be called before the WebApplication gets undeployed or stopped.
      Throws:
      WebBeansConfigurationException
    • getPlugins

      public List<org.apache.webbeans.spi.plugins.OpenWebBeansPlugin> getPlugins()
      Returns:
      an unmodifiable list of all registered {code OpenWebBeansPlugin}s
    • getEjbPlugin

      public org.apache.webbeans.spi.plugins.OpenWebBeansEjbPlugin getEjbPlugin()
      Gets ejb plugin
      Returns:
      ejb plugin
    • getEjbLCAPlugin

      public OpenWebBeansEjbLCAPlugin getEjbLCAPlugin()
      Gets ejb lifecycle annotations plugin
      Returns:
      ejb LCA plugin
    • getJmsPlugin

      public OpenWebBeansJmsPlugin getJmsPlugin()
      Gets the JMS plugin
      Returns:
      jms plugin
    • getJavaEEPlugin

      public org.apache.webbeans.spi.plugins.OpenWebBeansJavaEEPlugin getJavaEEPlugin()