Interface InterceptorHandler

All Known Implementing Classes:
DecoratorHandler, DefaultInterceptorHandler

public interface InterceptorHandler
An InterceptorHandler can be used to dynamically invoke methods on an internally stored target instance.
  • Method Summary

    Modifier and Type
    Method
    Description
    invoke(Method method, Object[] args)
    This method will get called whenever the proxy of the intercepted instance will get invoked.
  • Method Details

    • invoke

      Object invoke(Method method, Object[] args)
      This method will get called whenever the proxy of the intercepted instance will get invoked.
      Parameters:
      method - Method which should get invoked
      args - original invocation parameters
      Returns:
      the return value of the intercepted methos