Uses of Package
org.apache.webbeans.proxy
Packages that use org.apache.webbeans.proxy
Package
Description
-
Classes in org.apache.webbeans.proxy used by org.apache.webbeans.configClassDescriptionGenerate a dynamic subclass which has exactly 1 delegation point instance which get's set in the Constructor of the proxy.This factory creates proxies which delegate the method invocations 1:1 to an instance which gets resolved via a
Provider.This factory creates subclasses for abstract classes. -
Classes in org.apache.webbeans.proxy used by org.apache.webbeans.interceptClassDescriptionAn InterceptorHandler can be used to dynamically invoke methods on an internally stored target instance.
-
Classes in org.apache.webbeans.proxy used by org.apache.webbeans.portableClassDescriptionGenerate a dynamic subclass which has exactly 1 delegation point instance which get's set in the Constructor of the proxy.
-
Classes in org.apache.webbeans.proxy used by org.apache.webbeans.proxyClassDescriptionBase class for all OWB Proxy factoriesAn InterceptorHandler can be used to dynamically invoke methods on an internally stored target instance.Marker Interface for all OpenWebBeans Interceptor+Decorator Proxies.Interface for all OpenWebBeans
NormalScopeProxies.