org.apache.webbeans.util
Class SingleItemSet<T>

java.lang.Object
  extended by org.apache.webbeans.util.SingleItemSet<T>
All Implemented Interfaces:
Iterable<T>, Collection<T>, Set<T>

public class SingleItemSet<T>
extends Object
implements Set<T>

This is a special 'Set' which actually is no Collection but only contains a very single item. This way we keep mem low and also are pretty fast ;)


Nested Class Summary
 class SingleItemSet.SingleItemIterator
           
 
Constructor Summary
SingleItemSet(T instance)
           
 
Method Summary
 boolean add(T t)
           
 boolean addAll(Collection<? extends T> c)
           
 void clear()
           
 boolean contains(Object o)
           
 boolean containsAll(Collection<?> c)
           
 boolean isEmpty()
           
 Iterator<T> iterator()
           
 boolean remove(Object o)
           
 boolean removeAll(Collection<?> c)
           
 boolean retainAll(Collection<?> c)
           
 int size()
           
 Object[] toArray()
           
<T1> T1[]
toArray(T1[] a)
           
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 
Methods inherited from interface java.util.Set
equals, hashCode
 

Constructor Detail

SingleItemSet

public SingleItemSet(T instance)
Method Detail

size

public int size()
Specified by:
size in interface Collection<T>
Specified by:
size in interface Set<T>

isEmpty

public boolean isEmpty()
Specified by:
isEmpty in interface Collection<T>
Specified by:
isEmpty in interface Set<T>

contains

public boolean contains(Object o)
Specified by:
contains in interface Collection<T>
Specified by:
contains in interface Set<T>

iterator

public Iterator<T> iterator()
Specified by:
iterator in interface Iterable<T>
Specified by:
iterator in interface Collection<T>
Specified by:
iterator in interface Set<T>

toArray

public Object[] toArray()
Specified by:
toArray in interface Collection<T>
Specified by:
toArray in interface Set<T>

toArray

public <T1> T1[] toArray(T1[] a)
Specified by:
toArray in interface Collection<T>
Specified by:
toArray in interface Set<T>

add

public boolean add(T t)
Specified by:
add in interface Collection<T>
Specified by:
add in interface Set<T>

remove

public boolean remove(Object o)
Specified by:
remove in interface Collection<T>
Specified by:
remove in interface Set<T>

containsAll

public boolean containsAll(Collection<?> c)
Specified by:
containsAll in interface Collection<T>
Specified by:
containsAll in interface Set<T>

addAll

public boolean addAll(Collection<? extends T> c)
Specified by:
addAll in interface Collection<T>
Specified by:
addAll in interface Set<T>

retainAll

public boolean retainAll(Collection<?> c)
Specified by:
retainAll in interface Collection<T>
Specified by:
retainAll in interface Set<T>

removeAll

public boolean removeAll(Collection<?> c)
Specified by:
removeAll in interface Collection<T>
Specified by:
removeAll in interface Set<T>

clear

public void clear()
Specified by:
clear in interface Collection<T>
Specified by:
clear in interface Set<T>


Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.