Class StringUtil

java.lang.Object
org.apache.webbeans.util.StringUtil

public final class StringUtil extends Object
a few static string utility methods
  • Method Details

    • isEmpty

      public static boolean isEmpty(String val)
      Returns:
      true if the given string is either null or an empty string
    • isNotEmpty

      public static boolean isNotEmpty(String val)
      Returns:
      true if the given string is not null and has a content
    • isBlank

      public static boolean isBlank(String val)
      Returns:
      true if the given string is either null or an empty or blank string