Package org.apache.webbeans.util
package org.apache.webbeans.util
-
ClassDescriptionUtility class related with
Annotationoperations.Simple utility classes with some assertions methods.Utility classes with respect to the class operations.Utility classes for generic type operations.This is the internal helper class for low level access to JNDIDeprecated.use SecurityService insteadThis is a special 'Set' which actually is no Collection but only contains a very single item.This class contains a few helpers for handling @Specializes.a few static string utility methodsASetwhich only takes the externalForm as key instead the very expensive hashCode.Web beans related constants.Contains some utility methods used in the all project.