Serialized Form
-
Package org.apache.webbeans.annotation
-
Class org.apache.webbeans.annotation.AnyLiteral
class AnyLiteral extends EmptyAnnotationLiteral<jakarta.enterprise.inject.Any> implements Serializable- serialVersionUID:
- -8922048102786275371L
-
Class org.apache.webbeans.annotation.ApplicationScopeLiteral
class ApplicationScopeLiteral extends EmptyAnnotationLiteral<jakarta.enterprise.context.ApplicationScoped> implements Serializable- serialVersionUID:
- 8089948111744513390L
-
Class org.apache.webbeans.annotation.BeforeDestroyedLiteral
class BeforeDestroyedLiteral extends jakarta.enterprise.util.AnnotationLiteral<jakarta.enterprise.context.BeforeDestroyed> implements Serializable- serialVersionUID:
- 8867272511520063730L
-
Serialized Fields
-
value
Class<? extends Annotation> value
-
-
Class org.apache.webbeans.annotation.DefaultLiteral
class DefaultLiteral extends EmptyAnnotationLiteral<jakarta.enterprise.inject.Default> implements Serializable- serialVersionUID:
- 6788272256977634238L
-
Class org.apache.webbeans.annotation.DependentScopeLiteral
class DependentScopeLiteral extends EmptyAnnotationLiteral<jakarta.enterprise.context.Dependent> implements Serializable- serialVersionUID:
- -2677299920840834714L
-
Class org.apache.webbeans.annotation.DestroyedLiteral
class DestroyedLiteral extends jakarta.enterprise.util.AnnotationLiteral<jakarta.enterprise.context.Destroyed> implements Serializable- serialVersionUID:
- 8867272511520063730L
-
Serialized Fields
-
value
Class<? extends Annotation> value
-
-
Class org.apache.webbeans.annotation.EmptyAnnotationLiteral
class EmptyAnnotationLiteral extends jakarta.enterprise.util.AnnotationLiteral<T extends Annotation> implements Serializable-
Serialized Fields
-
annotationType
Class<T extends Annotation> annotationType
-
tostring
String tostring
-
-
-
Class org.apache.webbeans.annotation.InitializedLiteral
class InitializedLiteral extends jakarta.enterprise.util.AnnotationLiteral<jakarta.enterprise.context.Initialized> implements Serializable- serialVersionUID:
- 8867272511520063730L
-
Serialized Fields
-
value
Class<? extends Annotation> value
-
-
Class org.apache.webbeans.annotation.NamedLiteral
class NamedLiteral extends jakarta.enterprise.util.AnnotationLiteral<jakarta.inject.Named> implements Serializable- serialVersionUID:
- 8867272511520063730L
-
Serialized Fields
-
value
String value
-
-
Class org.apache.webbeans.annotation.RequestedScopeLiteral
class RequestedScopeLiteral extends EmptyAnnotationLiteral<jakarta.enterprise.context.RequestScoped> implements Serializable- serialVersionUID:
- -7333612898060695008L
-
Class org.apache.webbeans.annotation.SessionScopeLiteral
class SessionScopeLiteral extends EmptyAnnotationLiteral<jakarta.enterprise.context.SessionScoped> implements Serializable- serialVersionUID:
- -7469945140661485990L
-
-
Package org.apache.webbeans.component
-
Class org.apache.webbeans.component.CdiInterceptorBean
-
Serialized Fields
-
interceptorBindings
Set<Annotation> interceptorBindings
-
-
-
Class org.apache.webbeans.component.DecoratorBean
-
Serialized Fields
-
decoratedTypes
Set<Type> decoratedTypes
The Types the decorator itself implements -
delegateQualifiers
Set<Annotation> delegateQualifiers
The Qualifiers of the @Delegate injection point. -
delegateType
Type delegateType
The Type of the @Delegate injection point.
-
-
-
Class org.apache.webbeans.component.EjbInterceptorBean
-
Class org.apache.webbeans.component.InjectionTargetBean
-
Serialization Methods
-
writeReplace
This uses thePassivationBeanWrapperto only store the beanPassivationId.- Throws:
ObjectStreamException
-
-
Serialized Fields
-
-
Class org.apache.webbeans.component.InterceptorBean
-
Serialized Fields
-
-
Class org.apache.webbeans.component.ManagedBean
-
Serialized Fields
-
originalInjectionTarget
InjectionTargetImpl<T> originalInjectionTarget
-
-
-
Class org.apache.webbeans.component.PrincipalProvider
class PrincipalProvider extends Object implements Serializable-
Serialization Methods
-
readResolve
- Throws:
ObjectStreamException
-
-
-
Class org.apache.webbeans.component.ProducerAwareInjectionTargetBean
-
Serialization Methods
-
writeReplace
- Throws:
ObjectStreamException
-
-
Serialized Fields
-
producer
jakarta.enterprise.inject.spi.Producer<T> producer
-
-
-
Class org.apache.webbeans.component.ResourceProvider
class ResourceProvider extends Object implements Serializable-
Serialization Methods
-
readResolve
- Throws:
ObjectStreamException
-
-
Serialized Fields
-
resourceReference
org.apache.webbeans.spi.api.ResourceReference<T,
?> resourceReference
-
-
-
Class org.apache.webbeans.component.SelfInterceptorBean
-
-
Package org.apache.webbeans.container
-
Class org.apache.webbeans.container.InjectableBeanManager
class InjectableBeanManager extends Object implements Externalizable- serialVersionUID:
- 1L
-
Serialization Methods
-
readExternal
- Throws:
IOExceptionClassNotFoundException
-
writeExternal
- Throws:
IOException
-
-
Class org.apache.webbeans.container.SerializableBean
class SerializableBean extends Object implements Serializable- serialVersionUID:
- -8141263188006177021L
-
Serialization Methods
-
readObject
- Throws:
IOExceptionClassNotFoundException
-
writeObject
- Throws:
IOException
-
-
Serialized Fields
-
bean
jakarta.enterprise.inject.spi.Bean<T> bean
the delegated bean
-
-
-
Package org.apache.webbeans.context
-
Class org.apache.webbeans.context.AbstractContext
class AbstractContext extends Object implements Serializable- serialVersionUID:
- 2357678967444477818L
-
Serialization Methods
-
readObject
Read object.- Throws:
IOExceptionClassNotFoundException
-
writeObject
Write Object.- Throws:
IOException
-
-
Serialized Fields
-
active
boolean active
Context status, active or not -
componentInstanceMap
Map<jakarta.enterprise.context.spi.Contextual<?>,
BeanInstanceBag<?>> componentInstanceMap Context contextual instances -
scopeType
Class<? extends Annotation> scopeType
Contextual Scope Type
-
-
Class org.apache.webbeans.context.ApplicationContext
class ApplicationContext extends AbstractContext implements Serializable- serialVersionUID:
- -8254441824647652312L
-
Serialized Fields
-
destroyed
boolean destroyed
used to prevent us firing the Destroyed event twice. We cannot just use setActive(false) as this would trash @BeforeShutdown
-
-
Class org.apache.webbeans.context.ConversationContext
class ConversationContext extends PassivatingContext implements Externalizable- serialVersionUID:
- 2L
-
Serialization Methods
-
readExternal
- Throws:
IOExceptionClassNotFoundException
-
writeExternal
- Throws:
IOException
-
-
Class org.apache.webbeans.context.DependentContext
class DependentContext extends AbstractContext implements Serializable- serialVersionUID:
- 8225241216057316441L
-
Class org.apache.webbeans.context.PassivatingContext
class PassivatingContext extends AbstractContext implements Externalizable-
Serialization Methods
-
readExternal
- Throws:
IOExceptionClassNotFoundException
-
writeExternal
- Throws:
IOException
-
-
-
Class org.apache.webbeans.context.RequestContext
class RequestContext extends AbstractContext implements Serializable- serialVersionUID:
- -1030240915163272268L
-
Serialized Fields
-
httpSession
Object httpSession
if propagatedSessionContext != null the event instance to use (http session can be no more accessible) -
propagatedSessionContext
SessionContext propagatedSessionContext
If a Session gets destroyed in a HttpRequest then we store the session away and only destroy it at the end of the request.
-
-
Class org.apache.webbeans.context.SessionContext
class SessionContext extends PassivatingContext implements Externalizable- serialVersionUID:
- 2L
-
Serialization Methods
-
readExternal
- Throws:
IOExceptionClassNotFoundException
-
writeExternal
- Throws:
IOException
-
-
Class org.apache.webbeans.context.SingletonContext
class SingletonContext extends AbstractContext implements Serializable- serialVersionUID:
- -7600942820719243149L
-
-
Package org.apache.webbeans.context.control
-
Class org.apache.webbeans.context.control.ActivateRequestContextInterceptorBean
class ActivateRequestContextInterceptorBean extends Object implements Serializable-
Serialized Fields
-
webBeansContext
WebBeansContext webBeansContext
-
-
-
Class org.apache.webbeans.context.control.ActivateRequestContextInterceptorBean.ActivateRequestContextLiteral
class ActivateRequestContextLiteral extends EmptyAnnotationLiteral<jakarta.enterprise.context.control.ActivateRequestContext> implements Serializable -
Class org.apache.webbeans.context.control.ActivateRequestContextInterceptorBean.InterceptorClass
class InterceptorClass extends Object implements Serializable
-
-
Package org.apache.webbeans.context.creational
-
Class org.apache.webbeans.context.creational.BeanInstanceBag
class BeanInstanceBag extends Object implements Serializable- serialVersionUID:
- 1656996021599122499L
-
Class org.apache.webbeans.context.creational.CreationalContextImpl
class CreationalContextImpl extends Object implements Serializable- serialVersionUID:
- 1L
-
Serialization Methods
-
readObject
Read object.- Throws:
IOExceptionClassNotFoundException
-
writeObject
Write Object.- Throws:
IOException
-
-
Serialized Fields
-
bean
jakarta.enterprise.inject.spi.Bean<T> bean
Contains the currently created bean -
contextual
jakarta.enterprise.context.spi.Contextual<T> contextual
Contains the currently created contextual, may be a bean, interceptor or decorator -
dependentObjects
List<DependentCreationalContext<?>> dependentObjects
Contextual bean dependent instancesATTENTION This variable gets initiated lazily!
-
destroying
boolean destroying
This flag will get set totrueto prevent recursive loops while destroying the CreationContext. -
webBeansContext
WebBeansContext webBeansContext
-
-
Class org.apache.webbeans.context.creational.DependentCreationalContext
class DependentCreationalContext extends Object implements Serializable- serialVersionUID:
- 1L
-
Serialization Methods
-
readObject
- Throws:
IOExceptionClassNotFoundException
-
writeObject
- Throws:
IOException
-
-
Serialized Fields
-
-
Package org.apache.webbeans.conversation
-
Class org.apache.webbeans.conversation.ConversationImpl
class ConversationImpl extends Object implements Serializable- serialVersionUID:
- 8511063860333431722L
-
Serialization Methods
-
readObject
Initialize a few fields on deserialisation- Throws:
IOExceptionClassNotFoundException
-
-
Serialized Fields
-
id
String id
Conversation id -
isTransient
boolean isTransient
Transient or not. Transient conversations are destroyed at the end of the request -
lastAccessTime
long lastAccessTime
Active duration of the conversation -
timeout
long timeout
Default timeout is 30mins
-
-
Class org.apache.webbeans.conversation.ConversationStorageBean
class ConversationStorageBean extends Object implements Serializable
-
-
Package org.apache.webbeans.event
-
Class org.apache.webbeans.event.EventImpl
class EventImpl extends Object implements Serializable- serialVersionUID:
- 393021493190378023L
-
Serialization Methods
-
readObject
- Throws:
IOExceptionClassNotFoundException
-
-
Serialized Fields
-
metadata
EventMetadataImpl metadata
-
-
Class org.apache.webbeans.event.EventMetadataImpl
class EventMetadataImpl extends Object implements Serializable- serialVersionUID:
- -6401875861180683988L
-
Serialization Methods
-
readObject
- Throws:
IOExceptionClassNotFoundException
-
-
Serialized Fields
-
injectionPoint
jakarta.enterprise.inject.spi.InjectionPoint injectionPoint
-
qualifiers
Set<Annotation> qualifiers
-
selectType
Type selectType
-
type
Type type
-
-
-
Package org.apache.webbeans.exception
-
Exception org.apache.webbeans.exception.DuplicateDefinitionException
class DuplicateDefinitionException extends jakarta.enterprise.inject.spi.DefinitionException implements Serializable- serialVersionUID:
- 2312285271502063304L
-
Serialized Fields
-
msg
ExceptionMessageBuilder msg
-
-
Exception org.apache.webbeans.exception.InconsistentSpecializationException
class InconsistentSpecializationException extends jakarta.enterprise.inject.spi.DefinitionException implements Serializable- serialVersionUID:
- 5398575103682514128L
-
Serialized Fields
-
msg
ExceptionMessageBuilder msg
-
-
Exception org.apache.webbeans.exception.ProxyGenerationException
class ProxyGenerationException extends RuntimeException implements Serializable-
Serialized Fields
-
msg
ExceptionMessageBuilder msg
-
-
-
Exception org.apache.webbeans.exception.WebBeansConfigurationException
class WebBeansConfigurationException extends jakarta.enterprise.inject.spi.DefinitionException implements Serializable- serialVersionUID:
- 1863095663133791175L
-
Serialized Fields
-
msg
ExceptionMessageBuilder msg
-
-
Exception org.apache.webbeans.exception.WebBeansCreationException
class WebBeansCreationException extends WebBeansException implements Serializable- serialVersionUID:
- 1863095663133791175L
-
Serialized Fields
-
msg
ExceptionMessageBuilder msg
-
-
Exception org.apache.webbeans.exception.WebBeansDeploymentException
class WebBeansDeploymentException extends jakarta.enterprise.inject.spi.DeploymentException implements Serializable- serialVersionUID:
- 1863095663133791175L
-
Serialized Fields
-
msg
ExceptionMessageBuilder msg
-
-
Exception org.apache.webbeans.exception.WebBeansException
class WebBeansException extends RuntimeException implements Serializable- serialVersionUID:
- -3721839220664165557L
-
Serialized Fields
-
cause
Throwable cause
-
msg
ExceptionMessageBuilder msg
-
-
-
Package org.apache.webbeans.exception.helper
-
Class org.apache.webbeans.exception.helper.ExceptionMessageBuilder
class ExceptionMessageBuilder extends Object implements Serializable- serialVersionUID:
- 4391880458753108617L
-
-
Package org.apache.webbeans.inject.impl
-
Class org.apache.webbeans.inject.impl.InjectionPointImpl
class InjectionPointImpl extends Object implements Serializable- serialVersionUID:
- 1047233127758068484L
-
Serialization Methods
-
readObject
- Throws:
IOExceptionClassNotFoundException
-
writeObject
- Throws:
IOException
-
-
Serialized Fields
-
annotated
jakarta.enterprise.inject.spi.Annotated annotated
-
delegate
boolean delegate
-
injectionMember
Member injectionMember
-
injectionType
Type injectionType
-
ownerBean
jakarta.enterprise.inject.spi.Bean<?> ownerBean
-
qualifierAnnotations
Set<Annotation> qualifierAnnotations
-
transientt
boolean transientt
-
-
-
Package org.apache.webbeans.inject.instance
-
Class org.apache.webbeans.inject.instance.InstanceImpl
class InstanceImpl extends Object implements Serializable- serialVersionUID:
- -8401944412490389024L
-
Serialization Methods
-
readObject
- Throws:
IOExceptionClassNotFoundException
-
writeObject
- Throws:
IOException
-
-
Serialized Fields
-
creationalContexts
Map<Object,
CreationalContextImpl<?>> creationalContexts -
injectionClazz
Type injectionClazz
Injected class type -
injectionPoint
jakarta.enterprise.inject.spi.InjectionPoint injectionPoint
injection point, needed for injection into producer method and used to determine the BDA it was loaded from or null. -
qualifierAnnotations
Set<Annotation> qualifierAnnotations
Qualifier annotations appeared on the injection point -
strictValidation
boolean strictValidation
-
webBeansContext
WebBeansContext webBeansContext
-
-
-
Package org.apache.webbeans.intercept
-
Class org.apache.webbeans.intercept.ApplicationScopedBeanInterceptorHandler
class ApplicationScopedBeanInterceptorHandler extends NormalScopedBeanInterceptorHandler implements Serializable- serialVersionUID:
- 1L
-
Class org.apache.webbeans.intercept.DecoratorHandler
class DecoratorHandler extends Object implements Externalizable-
Serialization Methods
-
readExternal
- Throws:
IOExceptionClassNotFoundException
-
writeExternal
- Throws:
IOException
-
-
-
Class org.apache.webbeans.intercept.DefaultInterceptorHandler
class DefaultInterceptorHandler extends Object implements Externalizable-
Serialization Methods
-
readExternal
- Throws:
IOExceptionClassNotFoundException
-
writeExternal
- Throws:
IOException
-
-
-
Class org.apache.webbeans.intercept.NormalScopedBeanInterceptorHandler
class NormalScopedBeanInterceptorHandler extends Object implements Serializable-
Serialization Methods
-
readResolve
The following code gets generated into the proxy:Object writeReplace() throws ObjectStreamException { return provider; }- Throws:
ObjectStreamException
-
-
Serialized Fields
-
beanPassivationId
String beanPassivationId
The passivation if in case this is aPassivationCapablebean. we just keep this field for serializing it away
-
-
-
Class org.apache.webbeans.intercept.RequestScopedBeanInterceptorHandler
class RequestScopedBeanInterceptorHandler extends NormalScopedBeanInterceptorHandler implements Serializable- serialVersionUID:
- 1L
-
Class org.apache.webbeans.intercept.SessionScopedBeanInterceptorHandler
class SessionScopedBeanInterceptorHandler extends NormalScopedBeanInterceptorHandler implements Serializable- serialVersionUID:
- 1L
-
-
Package org.apache.webbeans.proxy