org.apache.webbeans.component
Class BeanAttributesImpl<T>
java.lang.Object
org.apache.webbeans.component.BeanAttributesImpl<T>
- All Implemented Interfaces:
- BeanAttributes<T>
- Direct Known Subclasses:
- AbstractOwbBean
public class BeanAttributesImpl<T>
- extends Object
- implements BeanAttributes<T>
|
Constructor Summary |
BeanAttributesImpl(Bean<T> bean)
TODO This constructor can be removed, when we move to CDI 1.1 since Bean extends BeanAttributes. |
BeanAttributesImpl(BeanAttributes<T> beanAttributes,
boolean nullable)
|
BeanAttributesImpl(Set<Type> types)
|
BeanAttributesImpl(Set<Type> types,
Set<Annotation> qualifiers)
|
BeanAttributesImpl(Set<Type> types,
Set<Annotation> qualifiers,
Class<? extends Annotation> scope)
|
BeanAttributesImpl(Set<Type> types,
Set<Annotation> qualifiers,
Class<? extends Annotation> scope,
Set<Class<? extends Annotation>> stereotypes)
|
BeanAttributesImpl(Set<Type> types,
Set<Annotation> qualifiers,
Class<? extends Annotation> scope,
String name,
boolean nullable,
Set<Class<? extends Annotation>> stereotypes,
boolean alternative)
|
| Methods inherited from class java.lang.Object |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
BeanAttributesImpl
public BeanAttributesImpl(Bean<T> bean)
- TODO This constructor can be removed, when we move to CDI 1.1 since
Bean extends BeanAttributes.
BeanAttributesImpl
public BeanAttributesImpl(BeanAttributes<T> beanAttributes,
boolean nullable)
BeanAttributesImpl
public BeanAttributesImpl(Set<Type> types)
BeanAttributesImpl
public BeanAttributesImpl(Set<Type> types,
Set<Annotation> qualifiers)
BeanAttributesImpl
public BeanAttributesImpl(Set<Type> types,
Set<Annotation> qualifiers,
Class<? extends Annotation> scope)
BeanAttributesImpl
public BeanAttributesImpl(Set<Type> types,
Set<Annotation> qualifiers,
Class<? extends Annotation> scope,
Set<Class<? extends Annotation>> stereotypes)
BeanAttributesImpl
public BeanAttributesImpl(Set<Type> types,
Set<Annotation> qualifiers,
Class<? extends Annotation> scope,
String name,
boolean nullable,
Set<Class<? extends Annotation>> stereotypes,
boolean alternative)
getTypes
public Set<Type> getTypes()
- Specified by:
getTypes in interface BeanAttributes<T>
getQualifiers
public Set<Annotation> getQualifiers()
- Specified by:
getQualifiers in interface BeanAttributes<T>
getScope
public Class<? extends Annotation> getScope()
- Specified by:
getScope in interface BeanAttributes<T>
getName
public String getName()
- Specified by:
getName in interface BeanAttributes<T>
isNullable
public boolean isNullable()
getStereotypes
public Set<Class<? extends Annotation>> getStereotypes()
- Specified by:
getStereotypes in interface BeanAttributes<T>
isAlternative
public boolean isAlternative()
- Specified by:
isAlternative in interface BeanAttributes<T>
Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.