Package org.apache.webbeans.component
Class ExtensionBean<T>
java.lang.Object
org.apache.webbeans.component.BeanAttributesImpl<T>
org.apache.webbeans.component.AbstractOwbBean<T>
org.apache.webbeans.component.BuiltInOwbBean<T>
org.apache.webbeans.component.ExtensionBean<T>
- Type Parameters:
T- type info
- All Implemented Interfaces:
jakarta.enterprise.context.spi.Contextual<T>,jakarta.enterprise.inject.spi.Bean<T>,jakarta.enterprise.inject.spi.BeanAttributes<T>,jakarta.enterprise.inject.spi.PassivationCapable,OwbBean<T>
Extension service bean definition.
- Version:
- $Rev$ $Date$
-
Field Summary
Fields inherited from class org.apache.webbeans.component.AbstractOwbBean
enabled, logger, passivatingId, specializedBean, webBeansContext, webBeansType -
Constructor Summary
ConstructorsConstructorDescriptionExtensionBean(WebBeansContext webBeansContext, Class<T> returnType) Creates a new extesion bean. -
Method Summary
Methods inherited from class org.apache.webbeans.component.BuiltInOwbBean
getProducerMethods inherited from class org.apache.webbeans.component.AbstractOwbBean
addToStringInfo, create, destroy, equals, getBeanClass, getId, getInjectionPoints, getLogger, getReturnType, getWebBeansContext, getWebBeansType, hashCode, isDependent, isEnabled, isPassivationCapable, isSpecializedBean, providedId, setEnabled, setSpecializedBean, toStringMethods inherited from class org.apache.webbeans.component.BeanAttributesImpl
getName, getQualifiers, getScope, getStereotypes, getTypes, isAlternativeMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface jakarta.enterprise.inject.spi.BeanAttributes
getName, getQualifiers, getScope, getStereotypes, getTypes, isAlternative
-
Constructor Details
-
ExtensionBean
Creates a new extesion bean.- Parameters:
returnType- return typewebBeansContext-
-
-
Method Details
-
proxyableType
- Specified by:
proxyableTypein classBuiltInOwbBean<T>- Returns:
- some built in beans can be decorated, this class is the one used to generate the proxy
-