org.apache.webbeans.component
Class InjectionPointBean
java.lang.Object
org.apache.webbeans.component.BeanAttributesImpl<T>
org.apache.webbeans.component.AbstractOwbBean<T>
org.apache.webbeans.component.BuiltInOwbBean<javax.enterprise.inject.spi.InjectionPoint>
org.apache.webbeans.component.InjectionPointBean
- All Implemented Interfaces:
- javax.enterprise.context.spi.Contextual<javax.enterprise.inject.spi.InjectionPoint>, javax.enterprise.inject.spi.Bean<javax.enterprise.inject.spi.InjectionPoint>, javax.enterprise.inject.spi.BeanAttributes<javax.enterprise.inject.spi.InjectionPoint>, javax.enterprise.inject.spi.PassivationCapable, OwbBean<javax.enterprise.inject.spi.InjectionPoint>
public class InjectionPointBean
- extends BuiltInOwbBean<javax.enterprise.inject.spi.InjectionPoint>
| Methods inherited from class org.apache.webbeans.component.AbstractOwbBean |
create, destroy, equals, getBeanClass, getId, getInjectionPoints, getLogger, getReturnType, getWebBeansContext, getWebBeansType, hashCode, isAlternative, isDependent, isEnabled, isSpecializedBean, providedId, setEnabled, setSpecializedBean, toString |
| Methods inherited from interface javax.enterprise.inject.spi.Bean |
isNullable |
| Methods inherited from interface javax.enterprise.inject.spi.BeanAttributes |
getName, getQualifiers, getScope, getStereotypes, getTypes |
InjectionPointBean
public InjectionPointBean(WebBeansContext webBeansContext)
isPassivationCapable
public boolean isPassivationCapable()
- Description copied from interface:
OwbBean
- True if passivation capable false otherwise.
- Specified by:
isPassivationCapable in interface OwbBean<javax.enterprise.inject.spi.InjectionPoint>- Overrides:
isPassivationCapable in class AbstractOwbBean<javax.enterprise.inject.spi.InjectionPoint>
- Returns:
- true if this bean is passivation capable
proxyableType
public Class<?> proxyableType()
- Specified by:
proxyableType in class BuiltInOwbBean<javax.enterprise.inject.spi.InjectionPoint>
- Returns:
- some built in beans can be decorated, this class is the one used to generate the proxy
Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.