org.apache.webbeans.component
Class InterceptorBean.MultiMethodInvocationContext

java.lang.Object
  extended by org.apache.webbeans.component.InterceptorBean.MultiMethodInvocationContext
All Implemented Interfaces:
javax.interceptor.InvocationContext
Enclosing class:
InterceptorBean<T>

public static class InterceptorBean.MultiMethodInvocationContext
extends Object
implements javax.interceptor.InvocationContext

An InvocationContext wraper for handling multiple interceptor methods. We will first make sure the own interceptor methods get handled and only then continue with the wrapped InvocationHandler.


Constructor Summary
InterceptorBean.MultiMethodInvocationContext(javax.interceptor.InvocationContext wrapped, javax.enterprise.inject.spi.InterceptionType interceptionType, Object instance, javax.enterprise.inject.spi.Interceptor interceptor)
           
 
Method Summary
 Constructor getConstructor()
           
 Map<String,Object> getContextData()
           
 int getCurrentInterceptorIdx()
           
 Method getMethod()
           
 Object[] getParameters()
           
 Object getTarget()
           
 Object getTimer()
           
 javax.interceptor.InvocationContext getWrapped()
           
 Object proceed()
           
 void setParameters(Object[] parameters)
           
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 

Constructor Detail

InterceptorBean.MultiMethodInvocationContext

public InterceptorBean.MultiMethodInvocationContext(javax.interceptor.InvocationContext wrapped,
                                                    javax.enterprise.inject.spi.InterceptionType interceptionType,
                                                    Object instance,
                                                    javax.enterprise.inject.spi.Interceptor interceptor)
Method Detail

getCurrentInterceptorIdx

public int getCurrentInterceptorIdx()

getWrapped

public javax.interceptor.InvocationContext getWrapped()

proceed

public Object proceed()
               throws Exception
Specified by:
proceed in interface javax.interceptor.InvocationContext
Throws:
Exception

getContextData

public Map<String,Object> getContextData()
Specified by:
getContextData in interface javax.interceptor.InvocationContext

getMethod

public Method getMethod()
Specified by:
getMethod in interface javax.interceptor.InvocationContext

getTarget

public Object getTarget()
Specified by:
getTarget in interface javax.interceptor.InvocationContext

getTimer

public Object getTimer()
Specified by:
getTimer in interface javax.interceptor.InvocationContext

getParameters

public Object[] getParameters()
Specified by:
getParameters in interface javax.interceptor.InvocationContext

setParameters

public void setParameters(Object[] parameters)
Specified by:
setParameters in interface javax.interceptor.InvocationContext

getConstructor

public Constructor getConstructor()
Specified by:
getConstructor in interface javax.interceptor.InvocationContext


Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.