org.apache.webbeans.component
Class InterceptorBean.MultiMethodInvocationContext

java.lang.Object
  extended by org.apache.webbeans.component.InterceptorBean.MultiMethodInvocationContext
All Implemented Interfaces:
InvocationContext
Enclosing class:
InterceptorBean<T>

public static class InterceptorBean.MultiMethodInvocationContext
extends Object
implements InvocationContext

An InvocationContext wraper for handling multiple interceptor methods. We will first make sure the own interceptor methods get handled and only then continue with the wrapped InvocationHandler.


Constructor Summary
InterceptorBean.MultiMethodInvocationContext(InvocationContext wrapped, InterceptionType interceptionType, Object instance, Interceptor interceptor)
           
 
Method Summary
 Constructor getConstructor()
           
 Map<String,Object> getContextData()
           
 int getCurrentInterceptorIdx()
           
 Method getMethod()
           
 Object[] getParameters()
           
 Object getTarget()
           
 Object getTimer()
           
 InvocationContext getWrapped()
           
 Object proceed()
           
 void setParameters(Object[] parameters)
           
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 

Constructor Detail

InterceptorBean.MultiMethodInvocationContext

public InterceptorBean.MultiMethodInvocationContext(InvocationContext wrapped,
                                                    InterceptionType interceptionType,
                                                    Object instance,
                                                    Interceptor interceptor)
Method Detail

getCurrentInterceptorIdx

public int getCurrentInterceptorIdx()

getWrapped

public InvocationContext getWrapped()

proceed

public Object proceed()
               throws Exception
Specified by:
proceed in interface InvocationContext
Throws:
Exception

getContextData

public Map<String,Object> getContextData()
Specified by:
getContextData in interface InvocationContext

getMethod

public Method getMethod()
Specified by:
getMethod in interface InvocationContext

getTarget

public Object getTarget()
Specified by:
getTarget in interface InvocationContext

getTimer

public Object getTimer()
Specified by:
getTimer in interface InvocationContext

getParameters

public Object[] getParameters()
Specified by:
getParameters in interface InvocationContext

setParameters

public void setParameters(Object[] parameters)
Specified by:
setParameters in interface InvocationContext

getConstructor

public Constructor getConstructor()


Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.