Package org.apache.webbeans.component
Class InterceptorMetadataBean<T>
java.lang.Object
org.apache.webbeans.component.BeanAttributesImpl<T>
org.apache.webbeans.component.AbstractOwbBean<T>
org.apache.webbeans.component.BuiltInOwbBean<jakarta.enterprise.inject.spi.Interceptor<T>>
org.apache.webbeans.component.InterceptorMetadataBean<T>
- All Implemented Interfaces:
jakarta.enterprise.context.spi.Contextual<jakarta.enterprise.inject.spi.Interceptor<T>>,jakarta.enterprise.inject.spi.Bean<jakarta.enterprise.inject.spi.Interceptor<T>>,jakarta.enterprise.inject.spi.BeanAttributes<jakarta.enterprise.inject.spi.Interceptor<T>>,jakarta.enterprise.inject.spi.PassivationCapable,OwbBean<jakarta.enterprise.inject.spi.Interceptor<T>>
public class InterceptorMetadataBean<T>
extends BuiltInOwbBean<jakarta.enterprise.inject.spi.Interceptor<T>>
Implicit metadata bean definition.
- Version:
- $Rev: 1493478 $ $Date: 2013-06-16 11:19:42 +0200 (So, 16 Jun 2013) $
-
Field Summary
Fields inherited from class org.apache.webbeans.component.AbstractOwbBean
enabled, logger, passivatingId, specializedBean, webBeansContext, webBeansType -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class org.apache.webbeans.component.BuiltInOwbBean
getProducerMethods inherited from class org.apache.webbeans.component.AbstractOwbBean
addToStringInfo, create, destroy, equals, getBeanClass, getId, getInjectionPoints, getLogger, getReturnType, getWebBeansContext, getWebBeansType, hashCode, isDependent, isEnabled, isSpecializedBean, providedId, setEnabled, setSpecializedBean, toStringMethods inherited from class org.apache.webbeans.component.BeanAttributesImpl
getName, getQualifiers, getScope, getStereotypes, getTypes, isAlternativeMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface jakarta.enterprise.inject.spi.BeanAttributes
getName, getQualifiers, getScope, getStereotypes, getTypes, isAlternative
-
Constructor Details
-
InterceptorMetadataBean
-
-
Method Details
-
isPassivationCapable
public boolean isPassivationCapable()Description copied from interface:OwbBeanTrue if passivation capable false otherwise.- Specified by:
isPassivationCapablein interfaceOwbBean<T>- Overrides:
isPassivationCapablein classAbstractOwbBean<jakarta.enterprise.inject.spi.Interceptor<T>>- Returns:
- true if this bean is passivation capable
-
proxyableType
- Specified by:
proxyableTypein classBuiltInOwbBean<jakarta.enterprise.inject.spi.Interceptor<T>>- Returns:
- some built in beans can be decorated, this class is the one used to generate the proxy
-