Package org.apache.webbeans.component
Class ResourceBean<X,T extends Annotation>
java.lang.Object
org.apache.webbeans.component.BeanAttributesImpl<T>
org.apache.webbeans.component.AbstractOwbBean<T>
org.apache.webbeans.component.AbstractProducerBean<T>
org.apache.webbeans.component.ProducerFieldBean<X>
org.apache.webbeans.component.ResourceBean<X,T>
- All Implemented Interfaces:
jakarta.enterprise.context.spi.Contextual<X>,jakarta.enterprise.inject.spi.Bean<X>,jakarta.enterprise.inject.spi.BeanAttributes<X>,jakarta.enterprise.inject.spi.PassivationCapable,OwbBean<X>
-
Field Summary
Fields inherited from class org.apache.webbeans.component.AbstractOwbBean
enabled, logger, passivatingId, specializedBean, webBeansContext, webBeansType -
Constructor Summary
ConstructorsConstructorDescriptionResourceBean(InjectionTargetBean<?> ownerComponent, org.apache.webbeans.spi.api.ResourceReference<X, T> resourceReference, jakarta.enterprise.inject.spi.BeanAttributes<X> beanAttributes, Class<X> beanClass, jakarta.enterprise.inject.spi.ProducerFactory<X> producerFactory) -
Method Summary
Modifier and TypeMethodDescriptionCalled after deserialization to get a new instance for some type of resource bean instance that are not serializable.booleanTrue if passivation capable false otherwise.Methods inherited from class org.apache.webbeans.component.ProducerFieldBean
addToStringInfo, create, getCreatorField, getId, setProducerFieldMethods inherited from class org.apache.webbeans.component.AbstractProducerBean
checkNullInstance, checkScopeType, getOwnerComponent, getProducer, getReturnType, isPassivationCapable, providedIdMethods inherited from class org.apache.webbeans.component.AbstractOwbBean
destroy, equals, getBeanClass, getInjectionPoints, getLogger, getWebBeansContext, getWebBeansType, hashCode, isDependent, isEnabled, isSpecializedBean, setEnabled, setSpecializedBean, toStringMethods inherited from class org.apache.webbeans.component.BeanAttributesImpl
getName, getQualifiers, getScope, getStereotypes, getTypes, isAlternativeMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface jakarta.enterprise.inject.spi.BeanAttributes
getName, getQualifiers, getScope, getStereotypes, getTypes, isAlternative
-
Constructor Details
-
ResourceBean
-
-
Method Details
-
getReference
-
getActualInstance
Called after deserialization to get a new instance for some type of resource bean instance that are not serializable. TODO: broken if producer is wrapped but surely better than actually serializing- Returns:
- a new instance of this resource bean.
-
isPassivationCapable
public boolean isPassivationCapable()Description copied from interface:OwbBeanTrue if passivation capable false otherwise.- Specified by:
isPassivationCapablein interfaceOwbBean<X>- Overrides:
isPassivationCapablein classProducerFieldBean<X>- Returns:
- true if this bean is passivation capable
-