org.apache.webbeans.component
Class ResourceBean<X,T extends Annotation>
java.lang.Object
org.apache.webbeans.component.BeanAttributesImpl<T>
org.apache.webbeans.component.AbstractOwbBean<T>
org.apache.webbeans.component.AbstractProducerBean<T>
org.apache.webbeans.component.ProducerFieldBean<X>
org.apache.webbeans.component.ResourceBean<X,T>
- All Implemented Interfaces:
- javax.enterprise.context.spi.Contextual<X>, javax.enterprise.inject.spi.Bean<X>, javax.enterprise.inject.spi.BeanAttributes<X>, javax.enterprise.inject.spi.PassivationCapable, OwbBean<X>
public class ResourceBean<X,T extends Annotation>
- extends ProducerFieldBean<X>
| Methods inherited from class org.apache.webbeans.component.AbstractOwbBean |
destroy, equals, getBeanClass, getInjectionPoints, getLogger, getWebBeansContext, getWebBeansType, hashCode, isAlternative, isDependent, isEnabled, isSpecializedBean, providedId, setEnabled, setSpecializedBean, toString |
| Methods inherited from interface javax.enterprise.inject.spi.Bean |
isNullable |
| Methods inherited from interface javax.enterprise.inject.spi.BeanAttributes |
getName, getQualifiers, getScope, getStereotypes, getTypes |
ResourceBean
public ResourceBean(InjectionTargetBean<?> ownerComponent,
ResourceReference<X,T> resourceReference,
javax.enterprise.inject.spi.BeanAttributes<X> beanAttributes,
Class<X> beanClass,
javax.enterprise.inject.spi.ProducerFactory<X> producerFactory)
getReference
public ResourceReference<X,T> getReference()
getActualInstance
public X getActualInstance()
- Called after deserialization to get a new instance for some type of resource bean instance that are
not serializable.
TODO: broken if producer is wrapped but surely better than actually serializing
- Returns:
- a new instance of this resource bean.
isPassivationCapable
public boolean isPassivationCapable()
- Description copied from interface:
OwbBean
- True if passivation capable false otherwise.
- Specified by:
isPassivationCapable in interface OwbBean<X>- Overrides:
isPassivationCapable in class ProducerFieldBean<X>
- Returns:
- true if this bean is passivation capable
Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.