org.apache.webbeans.component
Class ResourceBean<X,T extends Annotation>
java.lang.Object
org.apache.webbeans.component.BeanAttributesImpl<T>
org.apache.webbeans.component.AbstractOwbBean<T>
org.apache.webbeans.component.AbstractProducerBean<T>
org.apache.webbeans.component.ProducerFieldBean<X>
org.apache.webbeans.component.ResourceBean<X,T>
- All Implemented Interfaces:
- Contextual<X>, Bean<X>, PassivationCapable, OwbBean<X>, BeanAttributes<X>
public class ResourceBean<X,T extends Annotation>
- extends ProducerFieldBean<X>
| Methods inherited from class org.apache.webbeans.component.AbstractOwbBean |
destroy, getBeanClass, getInjectionPoints, getLogger, getWebBeansContext, getWebBeansType, isAlternative, isDependent, isEnabled, isSpecializedBean, setEnabled, setSpecializedBean, toString |
ResourceBean
public ResourceBean(InjectionTargetBean<?> ownerComponent,
ResourceReference<X,T> resourceReference,
BeanAttributesImpl<X> beanAttributes,
Class<X> beanClass)
getReference
public ResourceReference<X,T> getReference()
getActualInstance
public X getActualInstance()
- Called after deserialization to get a new instance for some type of resource bean instance that are
not serializable.
- Returns:
- a new instance of this resource bean.
isPassivationCapable
public boolean isPassivationCapable()
- Description copied from interface:
OwbBean
- True if passivation capable false otherwise.
- Specified by:
isPassivationCapable in interface OwbBean<X>- Overrides:
isPassivationCapable in class ProducerFieldBean<X>
- Returns:
- true if this bean is passivation capable
Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.