Package org.apache.webbeans.config
Class DefaultAnnotation
java.lang.Object
org.apache.webbeans.config.DefaultAnnotation
- All Implemented Interfaces:
Annotation,InvocationHandler
A small helper class to create a Annotation instance of the given annotation class
via
Proxy.
The annotation literal gets filled with the default values.
TODO implement class caching!-
Method Summary
Modifier and TypeMethodDescriptionClass<? extends Annotation>static Annotationof(Class<? extends Annotation> annotation) toString()Copied from jakarta.enterprise.util.AnnotationLiteral#toString() with minor changes.Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.annotation.Annotation
equals, hashCode
-
Method Details
-
of
-
invoke
- Specified by:
invokein interfaceInvocationHandler- Throws:
Throwable
-
annotationType
- Specified by:
annotationTypein interfaceAnnotation
-
toString
Copied from jakarta.enterprise.util.AnnotationLiteral#toString() with minor changes.- Specified by:
toStringin interfaceAnnotation- Overrides:
toStringin classObject- Returns:
-