org.apache.webbeans.config
Class DeploymentValidationService

java.lang.Object
  extended by org.apache.webbeans.config.DeploymentValidationService

public class DeploymentValidationService
extends Object


Nested Class Summary
static interface DeploymentValidationService.BeanInterceptorInfoProvider
           
 
Constructor Summary
DeploymentValidationService(WebBeansContext webBeansContext)
           
 
Method Summary
<T> void
validatePassivationCapable(OwbBean<T> bean)
          If bean is passivation capable, it validate all of its dependencies.
 javax.enterprise.inject.UnproxyableResolutionException validateProxyable(OwbBean<?> bean)
          Checks the unproxyable condition.
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 

Constructor Detail

DeploymentValidationService

public DeploymentValidationService(WebBeansContext webBeansContext)
Method Detail

validateProxyable

public javax.enterprise.inject.UnproxyableResolutionException validateProxyable(OwbBean<?> bean)
Checks the unproxyable condition.

Returns:
exception TCKs validate at runtime
Throws:
WebBeansConfigurationException - if bean is not proxied by the container

validatePassivationCapable

public <T> void validatePassivationCapable(OwbBean<T> bean)
If bean is passivation capable, it validate all of its dependencies.

Throws:
WebBeansConfigurationException - if not satisfy passivation dependencies


Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.