Package org.apache.webbeans.config
Class WebBeansContext
java.lang.Object
org.apache.webbeans.config.WebBeansContext
This is the central point to manage the whole CDI container
for a single application There is one WebBeansContext per BeanManagerImpl.
- Version:
- $Rev$ $Date$
-
Constructor Summary
ConstructorsConstructorDescriptionWebBeansContext(Map<Class<?>, Object> initialServices, Properties properties) -
Method Summary
Modifier and TypeMethodDescriptionvoidclear()Clear and destroy the whole WebBeansContext.static WebBeansContextMethod to be used when static use is truely unavoidable, such as serialization Ideally this method would never lazily create a WebBeansContext and as we don't want to do any deployment of new apps during deserialization, we want to rehydrate objects from an existing WebBeansContext which should be the active context.booleanfindMissingAnnotatedType(Class<?> missing) <T> Torg.apache.webbeans.spi.ApplicationBoundaryServiceorg.apache.webbeans.spi.BeanArchiveServicejakarta.enterprise.inject.spi.Bean<jakarta.enterprise.inject.spi.BeanManager>org.apache.webbeans.spi.ContextsServiceorg.apache.webbeans.spi.ConversationServicestatic WebBeansContextorg.apache.webbeans.spi.LoaderServiceorg.apache.webbeans.spi.ScannerServiceorg.apache.webbeans.spi.SecurityService<T> TgetService(Class<T> clazz) org.apache.webbeans.spi.TransactionService<T> voidregisterService(Class<T> clazz, T t)
-
Constructor Details
-
WebBeansContext
public WebBeansContext() -
WebBeansContext
-
-
Method Details
-
getBeanManagerBean
public jakarta.enterprise.inject.spi.Bean<jakarta.enterprise.inject.spi.BeanManager> getBeanManagerBean() -
getInjectableBeanManager
-
getInstance
-
currentInstance
Method to be used when static use is truely unavoidable, such as serialization Ideally this method would never lazily create a WebBeansContext and as we don't want to do any deployment of new apps during deserialization, we want to rehydrate objects from an existing WebBeansContext which should be the active context. This method could throw a runtime exception if no instance currently exists.- Returns:
-
getService
-
registerService
-
getInterceptorUtil
-
getInjectionPointFactory
-
getWebBeansUtil
-
getAnnotationManager
-
getConversationManager
-
getOpenWebBeansConfiguration
-
getAnnotatedElementFactory
-
getBeanManagerImpl
-
getSerializableBeanVault
-
getCreationalContextFactory
-
getDecoratorsManager
-
getStereoTypeManager
-
getAlternativesManager
-
getInterceptorsManager
-
getInterceptorResolutionService
-
getPluginLoader
-
getExtensionLoader
-
getInterceptorDecoratorProxyFactory
-
getNormalScopeProxyFactory
-
getSubclassProxyFactory
-
getTransactionService
public org.apache.webbeans.spi.TransactionService getTransactionService() -
getScannerService
public org.apache.webbeans.spi.ScannerService getScannerService() -
getContextsService
public org.apache.webbeans.spi.ContextsService getContextsService() -
getSecurityService
public org.apache.webbeans.spi.SecurityService getSecurityService() -
getBeanArchiveService
public org.apache.webbeans.spi.BeanArchiveService getBeanArchiveService() -
getNotificationManager
-
getConversationService
public org.apache.webbeans.spi.ConversationService getConversationService() -
get
-
clear
public void clear()Clear and destroy the whole WebBeansContext. This will also properly destroy all SPI services -
getLoaderService
public org.apache.webbeans.spi.LoaderService getLoaderService() -
getDeploymentValidationService
-
getApplicationBoundaryService
public org.apache.webbeans.spi.ApplicationBoundaryService getApplicationBoundaryService() -
findMissingAnnotatedType
-