|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||
java.lang.Objectorg.apache.webbeans.container.InjectionResolver
public class InjectionResolver
Injection point resolver class.
It is a singleton class per BeanManager. It is responsible for resolving the bean instances at the injection points for its bean manager.
WebBeansFinder| Constructor Summary | |
|---|---|
InjectionResolver(WebBeansContext webBeansContext)
Creates a new injection resolve for given bean manager. |
|
| Method Summary | ||
|---|---|---|
void |
checkInjectionPoint(InjectionPoint injectionPoint)
Check that a valid enabled bean exists in the deployment for the given injection point definition. |
|
void |
checkInjectionPointType(InjectionPoint injectionPoint)
Check the type of the injection point. |
|
void |
clearCaches()
Clear caches. |
|
Set<Bean<?>> |
findByAlternatives(Set<Bean<?>> result)
Gets alternatives from set. |
|
Set<Bean<?>> |
findByAlternatives(Set<Bean<?>> result,
String bdaBeansXMLFilePath)
Gets alternatives from set. |
|
Set<Bean<?>> |
findBySpecialization(Set<Bean<?>> result)
Returns specialized beans if exists, otherwise return input result |
|
Bean<?> |
getInjectionPointBean(InjectionPoint injectionPoint)
Returns bean for injection point. |
|
Set<Bean<?>> |
implResolveByName(String name)
Returns set of beans for given bean name. |
|
Set<Bean<?>> |
implResolveByType(boolean isDelegate,
Type injectionPointType,
Annotation... qualifiers)
Resolution by type. |
|
Set<Bean<?>> |
implResolveByType(boolean isDelegate,
Type injectionPointType,
Class<?> injectionPointClass,
Annotation... qualifiers)
Resolution by type. |
|
|
resolve(Set<Bean<? extends X>> beans)
|
|
|
resolveAll(Set<Bean<? extends X>> beans)
|
|
| Methods inherited from class java.lang.Object |
|---|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
| Constructor Detail |
|---|
public InjectionResolver(WebBeansContext webBeansContext)
webBeansContext - WebBeansContext| Method Detail |
|---|
public void clearCaches()
public void checkInjectionPointType(InjectionPoint injectionPoint)
Injection point type can not be TypeVariable.
injectionPoint - injection point
WebBeansConfigurationException - if not obey the rulepublic void checkInjectionPoint(InjectionPoint injectionPoint)
injectionPoint - injection point
WebBeansConfigurationException - If bean is not available in the current deployment for given injectionpublic Bean<?> getInjectionPointBean(InjectionPoint injectionPoint)
injectionPoint - injection point declaration
public Set<Bean<?>> implResolveByName(String name)
name - bean name
public Set<Bean<?>> implResolveByType(boolean isDelegate,
Type injectionPointType,
Annotation... qualifiers)
isDelegate - whether the InjectionPoint is for a DelegateinjectionPointType - injection point api typequalifiers - qualifiers of the injection point
public Set<Bean<?>> implResolveByType(boolean isDelegate,
Type injectionPointType,
Class<?> injectionPointClass,
Annotation... qualifiers)
isDelegate - whether the InjectionPoint is for a DelegateinjectionPointType - injection point api typequalifiers - qualifiers of the injection point
public Set<Bean<?>> findBySpecialization(Set<Bean<?>> result)
result - result beans
public Set<Bean<?>> findByAlternatives(Set<Bean<?>> result)
result - resolved set
public Set<Bean<?>> findByAlternatives(Set<Bean<?>> result,
String bdaBeansXMLFilePath)
result - resolved set
public <X> Bean<? extends X> resolve(Set<Bean<? extends X>> beans)
public <X> Set<Bean<? extends X>> resolveAll(Set<Bean<? extends X>> beans)
|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||