Package org.apache.webbeans.context
Class ApplicationContext
java.lang.Object
org.apache.webbeans.context.AbstractContext
org.apache.webbeans.context.ApplicationContext
- All Implemented Interfaces:
jakarta.enterprise.context.spi.AlterableContext,jakarta.enterprise.context.spi.Context,Serializable
Application context implementation.
- See Also:
-
Field Summary
Fields inherited from class org.apache.webbeans.context.AbstractContext
active, componentInstanceMap, scopeType -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoiddestroy()By default a Context destroys all it's Contextual Instances.voidThis method should only get called at container shutdown.booleanvoidMethods inherited from class org.apache.webbeans.context.AbstractContext
checkActive, destroy, destroyInstance, get, get, getInstance, getScope, isActive, setActive
-
Constructor Details
-
ApplicationContext
public ApplicationContext()
-
-
Method Details
-
setComponentInstanceMap
public void setComponentInstanceMap()Description copied from class:AbstractContext- Specified by:
setComponentInstanceMapin classAbstractContext
-
destroy
public void destroy()By default a Context destroys all it's Contextual Instances. But for the ApplicationContext we only need to destroy custom beans and _not_ Extensions and internal beans- Overrides:
destroyin classAbstractContext
-
destroySystemBeans
public void destroySystemBeans()This method should only get called at container shutdown. It will destroy the Extensions as well -
isDestroyed
public boolean isDestroyed()- Returns:
-