org.apache.webbeans.context
Class ApplicationContext
java.lang.Object
org.apache.webbeans.context.AbstractContext
org.apache.webbeans.context.ApplicationContext
- All Implemented Interfaces:
- Serializable, javax.enterprise.context.spi.AlterableContext, javax.enterprise.context.spi.Context
public class ApplicationContext
- extends AbstractContext
Application context implementation.
- See Also:
- Serialized Form
| Methods inherited from class java.lang.Object |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
ApplicationContext
public ApplicationContext()
setComponentInstanceMap
public void setComponentInstanceMap()
- Description copied from class:
AbstractContext
-
- Specified by:
setComponentInstanceMap in class AbstractContext
destroy
public void destroy()
- By default a Context destroys all it's Contextual Instances.
But for the ApplicationContext we only need to destroy custom beans and _not_ Extensions and internal beans
- Overrides:
destroy in class AbstractContext
destroySystemBeans
public void destroySystemBeans()
- This method should only get called at container shutdown.
It will destroy the Extensions as well
isDestroyed
public boolean isDestroyed()
- Returns:
- @{code true} if custom beans already got destroyed
Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.