org.apache.webbeans.context
Class ConversationContext
java.lang.Object
org.apache.webbeans.context.AbstractContext
org.apache.webbeans.context.PassivatingContext
org.apache.webbeans.context.ConversationContext
- All Implemented Interfaces:
- Externalizable, Serializable, javax.enterprise.context.spi.AlterableContext, javax.enterprise.context.spi.Context
public class ConversationContext
- extends PassivatingContext
- implements Serializable
Conversation context implementation.
This reflects THE current Conversation (there can only be one active at a time for a thread).
It should not be confused with the Map of conversationId -> Conversation
which we internally store in the SessionContext.
- See Also:
- Serialized Form
| Methods inherited from class java.lang.Object |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
ConversationContext
public ConversationContext()
ConversationContext
public ConversationContext(WebBeansContext webBeansContext)
- Constructor
setComponentInstanceMap
public void setComponentInstanceMap()
- Description copied from class:
AbstractContext
-
- Specified by:
setComponentInstanceMap in class AbstractContext
getConversation
public ConversationImpl getConversation()
Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.