Package org.apache.webbeans.context
Class RequestContext
java.lang.Object
org.apache.webbeans.context.AbstractContext
org.apache.webbeans.context.RequestContext
- All Implemented Interfaces:
jakarta.enterprise.context.spi.AlterableContext,jakarta.enterprise.context.spi.Context,Serializable
Request context implementation.
- See Also:
-
Field Summary
Fields inherited from class org.apache.webbeans.context.AbstractContext
active, componentInstanceMap, scopeType -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoiddestroy(jakarta.enterprise.context.spi.Contextual<?> contextual) The base object for the current RequestContext.voidvoidsetHttpSession(Object httpSession) voidsetPropagatedSessionContext(SessionContext propagatedSessionContext) Methods inherited from class org.apache.webbeans.context.AbstractContext
checkActive, destroy, destroyInstance, get, get, getInstance, getScope, isActive, setActive
-
Constructor Details
-
RequestContext
public RequestContext()
-
-
Method Details
-
setComponentInstanceMap
public void setComponentInstanceMap()Description copied from class:AbstractContext- Specified by:
setComponentInstanceMapin classAbstractContext
-
getRequestObject
The base object for the current RequestContext. For a synthetic 'request' this is null. For a real http ServletRequest this is the HttpServletRequest. This is what gets used as payload for variousInitializedandDestroyedevents. This can be overloaded in web requests.- Returns:
- the ServletRequest or
nullfor other kind of requests‚
-
setPropagatedSessionContext
-
getPropagatedSessionContext
- Returns:
- the SessionContext to get destroyed at the end of the request or
nullotherwise
-
getHttpSession
-
setHttpSession
-
destroy
public void destroy(jakarta.enterprise.context.spi.Contextual<?> contextual) - Specified by:
destroyin interfacejakarta.enterprise.context.spi.AlterableContext- Overrides:
destroyin classAbstractContext
-