org.apache.webbeans.context
Class RequestContext

java.lang.Object
  extended by org.apache.webbeans.context.AbstractContext
      extended by org.apache.webbeans.context.RequestContext
All Implemented Interfaces:
Serializable, javax.enterprise.context.spi.AlterableContext, javax.enterprise.context.spi.Context

public class RequestContext
extends AbstractContext

Request context implementation.

See Also:
Serialized Form

Field Summary
 
Fields inherited from class org.apache.webbeans.context.AbstractContext
active, componentInstanceMap, scopeType
 
Constructor Summary
RequestContext()
           
 
Method Summary
 void destroy(javax.enterprise.context.spi.Contextual<?> contextual)
           
 SessionContext getPropagatedSessionContext()
           
 Object getRequestObject()
          The base object for the current RequestContext.
 void setComponentInstanceMap()
          
 void setPropagatedSessionContext(SessionContext propagatedSessionContext)
           
 
Methods inherited from class org.apache.webbeans.context.AbstractContext
checkActive, destroy, destroyInstance, get, get, getInstance, getScope, isActive, setActive
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 

Constructor Detail

RequestContext

public RequestContext()
Method Detail

setComponentInstanceMap

public void setComponentInstanceMap()
Description copied from class: AbstractContext

Specified by:
setComponentInstanceMap in class AbstractContext

getRequestObject

public Object getRequestObject()
The base object for the current RequestContext. For a synthetic 'request' this is null. For a real http ServletRequest this is the HttpServletRequest. This is what gets used as payload for various Initialized and Destroyed events. This can be overloaded in web requests.

Returns:
the ServletRequest or null for other kind of requests‚

setPropagatedSessionContext

public void setPropagatedSessionContext(SessionContext propagatedSessionContext)

getPropagatedSessionContext

public SessionContext getPropagatedSessionContext()
Returns:
the SessionContext to get destroyed at the end of the request or null otherwise

destroy

public void destroy(javax.enterprise.context.spi.Contextual<?> contextual)
Specified by:
destroy in interface javax.enterprise.context.spi.AlterableContext
Overrides:
destroy in class AbstractContext


Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.