org.apache.webbeans.event
Interface OwbObserverMethod<T>
- All Superinterfaces:
- ObserverMethod<T>
- All Known Implementing Classes:
- ObserverMethodImpl
public interface OwbObserverMethod<T>
- extends ObserverMethod<T>
This interface fixes an issue of the CDI API. See https://issues.jboss.org/browse/CDI-36
|
Method Summary |
void |
notify(T event,
EventMetadata metadata)
will actually call the underlying observer method with the specified event metadata |
notify
void notify(T event,
EventMetadata metadata)
- will actually call the underlying observer method with the specified event metadata
Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.