|
||||||||||
| PREV NEXT | FRAMES NO FRAMES | |||||||||
| Packages that use WebBeansConfigurationException | |
|---|---|
| org.apache.webbeans.config | |
| org.apache.webbeans.plugins | |
| org.apache.webbeans.util | |
| Uses of WebBeansConfigurationException in org.apache.webbeans.config |
|---|
| Methods in org.apache.webbeans.config that throw WebBeansConfigurationException | |
|---|---|
static boolean |
EJBWebBeansConfigurator.isSessionBean(Class<?> clazz,
WebBeansContext webBeansContext)
Returns true if given class is an deployed ejb bean class, false otherwise. |
void |
OpenWebBeansConfiguration.parseConfiguration()
(re)read the configuration from the resources in the classpath. |
| Uses of WebBeansConfigurationException in org.apache.webbeans.plugins |
|---|
| Methods in org.apache.webbeans.plugins that throw WebBeansConfigurationException | |
|---|---|
void |
PluginLoader.shutDown()
Tell all the plugins to free up all locked resources. |
void |
PluginLoader.startUp()
load and startup all registered plugins. |
static void |
PluginLoader.throwsException(Exception e)
|
| Uses of WebBeansConfigurationException in org.apache.webbeans.util |
|---|
| Methods in org.apache.webbeans.util that throw WebBeansConfigurationException | ||
|---|---|---|
|
WebBeansUtil.checkManagedBeanCondition(AnnotatedType<X> type)
Checks the implementation class for checking conditions. |
|
void |
WebBeansUtil.checkManagedBeanCondition(Class<?> clazz)
|
|
boolean |
WebBeansUtil.isConstructorOk(Class<?> clazz)
Check that simple web beans class has compatible constructor. |
|
|
||||||||||
| PREV NEXT | FRAMES NO FRAMES | |||||||||