org.apache.webbeans.inject
Class AbstractInjectable<T>
java.lang.Object
org.apache.webbeans.inject.AbstractInjectable<T>
- Direct Known Subclasses:
- InjectableConstructor, InjectableField, InjectableMethod
public abstract class AbstractInjectable<T>
- extends Object
Abstract implementation of all components which are injectable.
Do actual injection via inject(InjectionPoint)
- See Also:
InjectableField,
InjectableConstructor,
InjectableMethod
|
Method Summary |
protected static List<javax.enterprise.inject.spi.InjectionPoint> |
createInjectionPoints(javax.enterprise.inject.spi.Producer<?> owner,
Member member)
|
protected javax.enterprise.context.spi.Contextual<?> |
getBean()
|
protected List<javax.enterprise.inject.spi.InjectionPoint> |
getInjectionPoints(Member member)
Returns injection points related with given member type of the bean. |
protected WebBeansContext |
getWebBeansContext()
|
T |
inject(javax.enterprise.inject.spi.InjectionPoint injectionPoint)
Gets the injected bean instance in its scoped context. |
| Methods inherited from class java.lang.Object |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
owner
protected javax.enterprise.inject.spi.Producer<?> owner
creationalContext
protected final CreationalContextImpl<?> creationalContext
transientCreationalContext
protected CreationalContextImpl<?> transientCreationalContext
AbstractInjectable
protected AbstractInjectable(javax.enterprise.inject.spi.Producer<?> owner,
CreationalContextImpl<?> creationalContext)
inject
public T inject(javax.enterprise.inject.spi.InjectionPoint injectionPoint)
- Gets the injected bean instance in its scoped context.
- Parameters:
injectionPoint - injection point definition
- Returns:
- current bean instance in the resolved bean scope
getBean
protected javax.enterprise.context.spi.Contextual<?> getBean()
getWebBeansContext
protected WebBeansContext getWebBeansContext()
getInjectionPoints
protected List<javax.enterprise.inject.spi.InjectionPoint> getInjectionPoints(Member member)
- Returns injection points related with given member type of the bean.
- Parameters:
member - java member
- Returns:
- injection points related with given member type
createInjectionPoints
protected static List<javax.enterprise.inject.spi.InjectionPoint> createInjectionPoints(javax.enterprise.inject.spi.Producer<?> owner,
Member member)
Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.