org.apache.webbeans.inject
Class AbstractInjectable<T>

java.lang.Object
  extended by org.apache.webbeans.inject.AbstractInjectable<T>
Direct Known Subclasses:
InjectableConstructor, InjectableField, InjectableMethod

public abstract class AbstractInjectable<T>
extends Object

Abstract implementation of all components which are injectable.

Do actual injection via inject(InjectionPoint)

See Also:
InjectableField, InjectableConstructor, InjectableMethod

Field Summary
protected  CreationalContextImpl<?> creationalContext
           
 
Constructor Summary
protected AbstractInjectable(Producer<?> owner, CreationalContextImpl<?> creationalContext)
           
 
Method Summary
protected static List<InjectionPoint> createInjectionPoints(Producer<?> owner, Member member)
           
protected  Contextual<?> getBean()
           
protected  List<InjectionPoint> getInjectionPoints(Member member)
          Returns injection points related with given member type of the bean.
protected  WebBeansContext getWebBeansContext()
           
 T inject(InjectionPoint injectionPoint)
          Gets the injected bean instance in its scoped context.
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 

Field Detail

creationalContext

protected final CreationalContextImpl<?> creationalContext
Constructor Detail

AbstractInjectable

protected AbstractInjectable(Producer<?> owner,
                             CreationalContextImpl<?> creationalContext)
Method Detail

inject

public T inject(InjectionPoint injectionPoint)
Gets the injected bean instance in its scoped context.

Parameters:
injectionPoint - injection point definition
Returns:
current bean instance in the resolved bean scope

getBean

protected Contextual<?> getBean()

getWebBeansContext

protected WebBeansContext getWebBeansContext()

getInjectionPoints

protected List<InjectionPoint> getInjectionPoints(Member member)
Returns injection points related with given member type of the bean.

Parameters:
member - java member
Returns:
injection points related with given member type

createInjectionPoints

protected static List<InjectionPoint> createInjectionPoints(Producer<?> owner,
                                                            Member member)


Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.