org.apache.webbeans.inject
Class AbstractInjectable<T>
java.lang.Object
org.apache.webbeans.inject.AbstractInjectable<T>
- Direct Known Subclasses:
- InjectableConstructor, InjectableField, InjectableMethod
public abstract class AbstractInjectable<T>
- extends Object
Abstract implementation of all components which are injectable.
Do actual injection via inject(InjectionPoint)
- See Also:
InjectableField,
InjectableConstructor,
InjectableMethod
| Methods inherited from class java.lang.Object |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
creationalContext
protected final CreationalContextImpl<?> creationalContext
AbstractInjectable
protected AbstractInjectable(Producer<?> owner,
CreationalContextImpl<?> creationalContext)
inject
public T inject(InjectionPoint injectionPoint)
- Gets the injected bean instance in its scoped context.
- Parameters:
injectionPoint - injection point definition
- Returns:
- current bean instance in the resolved bean scope
getBean
protected Contextual<?> getBean()
getWebBeansContext
protected WebBeansContext getWebBeansContext()
getInjectionPoints
protected List<InjectionPoint> getInjectionPoints(Member member)
- Returns injection points related with given member type of the bean.
- Parameters:
member - java member
- Returns:
- injection points related with given member type
createInjectionPoints
protected static List<InjectionPoint> createInjectionPoints(Producer<?> owner,
Member member)
Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.