|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||
java.lang.Objectorg.apache.webbeans.intercept.InterceptorResolutionService
public class InterceptorResolutionService
Class to calculate interceptor resolution information. It also handles the proxy caching and applying.
| Nested Class Summary | |
|---|---|
static class |
InterceptorResolutionService.BeanInterceptorInfo
static information about interceptors and decorators for a single bean. |
static class |
InterceptorResolutionService.BusinessMethodInterceptorInfo
We track per method which Interceptors to invoke |
static class |
InterceptorResolutionService.LifecycleMethodInfo
|
| Constructor Summary | |
|---|---|
InterceptorResolutionService(WebBeansContext webBeansContext)
|
|
| Method Summary | ||
|---|---|---|
|
calculateInterceptorInfo(Set<Type> beanTypes,
Set<Annotation> qualifiers,
AnnotatedType<T> annotatedType)
|
|
| Methods inherited from class java.lang.Object |
|---|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
| Constructor Detail |
|---|
public InterceptorResolutionService(WebBeansContext webBeansContext)
| Method Detail |
|---|
public <T> InterceptorResolutionService.BeanInterceptorInfo calculateInterceptorInfo(Set<Type> beanTypes,
Set<Annotation> qualifiers,
AnnotatedType<T> annotatedType)
|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||