Package org.apache.webbeans.intercept
Class InterceptorResolutionService.BusinessMethodInterceptorInfo
java.lang.Object
org.apache.webbeans.intercept.InterceptorResolutionService.BusinessMethodInterceptorInfo
- Enclosing class:
- InterceptorResolutionService
We track per method which Interceptors to invoke
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionjakarta.enterprise.inject.spi.Interceptor<?>[]The (sorted) CDI Interceptor Beans for a specific method ornullif no Interceptor exists for this method.jakarta.enterprise.inject.spi.Interceptor<?>[]The (sorted) EJB-style (Interceptors) Interceptor Beans for a specific method ornullif no Interceptor exists for this method.LinkedHashMap<jakarta.enterprise.inject.spi.Decorator<?>,Method> The (sorted) Decorator Beans for a specific method ornullif no Decorator exists for this method.booleanisEmpty()Determine if any interceptor information has been set at all.voidsetCdiInterceptorBindings(Set<Annotation> bindings) voidsetCdiInterceptors(List<jakarta.enterprise.inject.spi.Interceptor<?>> cdiInterceptors) voidsetEjbInterceptors(List<jakarta.enterprise.inject.spi.Interceptor<?>> ejbInterceptors) voidsetMethodDecorators(LinkedHashMap<jakarta.enterprise.inject.spi.Decorator<?>, Method> methodDecorators)
-
Constructor Details
-
BusinessMethodInterceptorInfo
public BusinessMethodInterceptorInfo()
-
-
Method Details
-
getEjbInterceptors
public jakarta.enterprise.inject.spi.Interceptor<?>[] getEjbInterceptors()The (sorted) EJB-style (Interceptors) Interceptor Beans for a specific method ornullif no Interceptor exists for this method. They must be called before thecdiInterceptors! -
getCdiInterceptors
public jakarta.enterprise.inject.spi.Interceptor<?>[] getCdiInterceptors()The (sorted) CDI Interceptor Beans for a specific method ornullif no Interceptor exists for this method. -
getCdiInterceptorBindings
-
setCdiInterceptorBindings
-
getMethodDecorators
The (sorted) Decorator Beans for a specific method ornullif no Decorator exists for this method. This Map is sorted! Key: the Decorator Bean Value: the decorating method from the decorator instance -
setCdiInterceptors
-
setMethodDecorators
public void setMethodDecorators(LinkedHashMap<jakarta.enterprise.inject.spi.Decorator<?>, Method> methodDecorators) -
setEjbInterceptors
-
isEmpty
public boolean isEmpty()Determine if any interceptor information has been set at all.
-