org.apache.webbeans.intercept
Class InterceptorResolutionService.BusinessMethodInterceptorInfo

java.lang.Object
  extended by org.apache.webbeans.intercept.InterceptorResolutionService.BusinessMethodInterceptorInfo
Enclosing class:
InterceptorResolutionService

public static class InterceptorResolutionService.BusinessMethodInterceptorInfo
extends Object

We track per method which Interceptors to invoke


Constructor Summary
InterceptorResolutionService.BusinessMethodInterceptorInfo()
           
 
Method Summary
 Interceptor<?>[] getCdiInterceptors()
          The (sorted) CDI Interceptor Beans for a specific method or null if no Interceptor exists for this method.
 Interceptor<?>[] getEjbInterceptors()
          The (sorted) EJB-style (Interceptors) Interceptor Beans for a specific method or null if no Interceptor exists for this method.
 LinkedHashMap<Decorator<?>,Method> getMethodDecorators()
          The (sorted) Decorator Beans for a specific method or null if no Decorator exists for this method.
 boolean isEmpty()
          Determine if any interceptor information has been set at all.
 void setCdiInterceptors(List<Interceptor<?>> cdiInterceptors)
           
 void setEjbInterceptors(List<Interceptor<?>> ejbInterceptors)
           
 void setMethodDecorators(LinkedHashMap<Decorator<?>,Method> methodDecorators)
           
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 

Constructor Detail

InterceptorResolutionService.BusinessMethodInterceptorInfo

public InterceptorResolutionService.BusinessMethodInterceptorInfo()
Method Detail

getEjbInterceptors

public Interceptor<?>[] getEjbInterceptors()
The (sorted) EJB-style (Interceptors) Interceptor Beans for a specific method or null if no Interceptor exists for this method. They must be called before the cdiInterceptors!


getCdiInterceptors

public Interceptor<?>[] getCdiInterceptors()
The (sorted) CDI Interceptor Beans for a specific method or null if no Interceptor exists for this method.


getMethodDecorators

public LinkedHashMap<Decorator<?>,Method> getMethodDecorators()
The (sorted) Decorator Beans for a specific method or null if no Decorator exists for this method. This Map is sorted! Key: the Decorator Bean Value: the decorating method from the decorator instance


setCdiInterceptors

public void setCdiInterceptors(List<Interceptor<?>> cdiInterceptors)

setMethodDecorators

public void setMethodDecorators(LinkedHashMap<Decorator<?>,Method> methodDecorators)

setEjbInterceptors

public void setEjbInterceptors(List<Interceptor<?>> ejbInterceptors)

isEmpty

public boolean isEmpty()
Determine if any interceptor information has been set at all.



Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.