|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||
java.lang.Objectorg.apache.webbeans.intercept.InterceptorResolutionService.BusinessMethodInterceptorInfo
public static class InterceptorResolutionService.BusinessMethodInterceptorInfo
We track per method which Interceptors to invoke
| Constructor Summary | |
|---|---|
InterceptorResolutionService.BusinessMethodInterceptorInfo()
|
|
| Method Summary | |
|---|---|
Interceptor<?>[] |
getCdiInterceptors()
The (sorted) CDI Interceptor Beans for a specific method or null
if no Interceptor exists for this method. |
Interceptor<?>[] |
getEjbInterceptors()
The (sorted) EJB-style ( Interceptors)
Interceptor Beans for a specific method or null
if no Interceptor exists for this method. |
LinkedHashMap<Decorator<?>,Method> |
getMethodDecorators()
The (sorted) Decorator Beans for a specific method or null
if no Decorator exists for this method. |
boolean |
isEmpty()
Determine if any interceptor information has been set at all. |
void |
setCdiInterceptors(List<Interceptor<?>> cdiInterceptors)
|
void |
setEjbInterceptors(List<Interceptor<?>> ejbInterceptors)
|
void |
setMethodDecorators(LinkedHashMap<Decorator<?>,Method> methodDecorators)
|
| Methods inherited from class java.lang.Object |
|---|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
| Constructor Detail |
|---|
public InterceptorResolutionService.BusinessMethodInterceptorInfo()
| Method Detail |
|---|
public Interceptor<?>[] getEjbInterceptors()
Interceptors)
Interceptor Beans for a specific method or null
if no Interceptor exists for this method.
They must be called before the cdiInterceptors!
public Interceptor<?>[] getCdiInterceptors()
null
if no Interceptor exists for this method.
public LinkedHashMap<Decorator<?>,Method> getMethodDecorators()
null
if no Decorator exists for this method.
This Map is sorted!
Key: the Decorator Bean
Value: the decorating method from the decorator instance
public void setCdiInterceptors(List<Interceptor<?>> cdiInterceptors)
public void setMethodDecorators(LinkedHashMap<Decorator<?>,Method> methodDecorators)
public void setEjbInterceptors(List<Interceptor<?>> ejbInterceptors)
public boolean isEmpty()
|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||