org.apache.webbeans.intercept
Class NormalScopedBeanInterceptorHandler
java.lang.Object
org.apache.webbeans.intercept.NormalScopedBeanInterceptorHandler
- All Implemented Interfaces:
- Serializable, Provider
- Direct Known Subclasses:
- ApplicationScopedBeanInterceptorHandler
public class NormalScopedBeanInterceptorHandler
- extends Object
- implements Provider, Serializable
A Provider which handles all NormalScoped proxying.
It's two main responsibilities are to provide the one active
Contextual Instance, the second is to provide serialisation.
The generated proxy will writeReplace() with this class and any
NormalScopedBean provider must readResolve() and regenerate the
proxy class from the NormalScopeProxyFactory
again.
Any subclass should either declare all their fields transient
or handle the serialisation properly!
- See Also:
- Serialized Form
| Methods inherited from class java.lang.Object |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
bean
protected transient Bean<?> bean
NormalScopedBeanInterceptorHandler
public NormalScopedBeanInterceptorHandler(BeanManager beanManager,
Bean<?> bean)
get
public Object get()
- Specified by:
get in interface Provider
getBean
public Bean<?> getBean()
getBeanManager
protected BeanManager getBeanManager()
getContextualInstance
protected Object getContextualInstance()
readResolve
protected Object readResolve()
throws ObjectStreamException
- The following code gets generated into the proxy:
Object writeReplace() throws ObjectStreamException
{
return provider;
}
- Throws:
ObjectStreamException
Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.