Package org.apache.webbeans.plugins
Class PluginLoader
java.lang.Object
org.apache.webbeans.plugins.PluginLoader
OpenWebBeans plugins are used to extend 'core' functionality of the injection mechanism with functionality of other frameworks.
Core functionality are all parts which are available in a standard JDK-1.5 SE runtime. Extended functionality are things like JPA, JSF, EJB etc.
The plugin mechanism is based on the ServiceProvider functionality.
A jar containing an OWB plugin has to expose itself in the file
META-INF/services/org.apache.webbeans.plugins.OpenWebBeansPlugin
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionGets ejb lifecycle annotations pluginorg.apache.webbeans.spi.plugins.OpenWebBeansEjbPluginGets ejb pluginorg.apache.webbeans.spi.plugins.OpenWebBeansJavaEEPluginGets the JMS pluginList<org.apache.webbeans.spi.plugins.OpenWebBeansPlugin>voidshutDown()Tell all the plugins to free up all locked resources.voidstartUp()load and startup all registered plugins.static void
-
Constructor Details
-
PluginLoader
public PluginLoader()
-
-
Method Details
-
startUp
load and startup all registered plugins. This must be called once the WebApplication is started.- Throws:
WebBeansConfigurationException
-
throwsException
- Throws:
WebBeansConfigurationException
-
shutDown
Tell all the plugins to free up all locked resources. This must be called before the WebApplication gets undeployed or stopped.- Throws:
WebBeansConfigurationException
-
getPlugins
- Returns:
- an unmodifiable list of all registered {code OpenWebBeansPlugin}s
-
getEjbPlugin
public org.apache.webbeans.spi.plugins.OpenWebBeansEjbPlugin getEjbPlugin()Gets ejb plugin- Returns:
- ejb plugin
-
getEjbLCAPlugin
Gets ejb lifecycle annotations plugin- Returns:
- ejb LCA plugin
-
getJmsPlugin
Gets the JMS plugin- Returns:
- jms plugin
-
getJavaEEPlugin
public org.apache.webbeans.spi.plugins.OpenWebBeansJavaEEPlugin getJavaEEPlugin()
-