Package org.apache.webbeans.proxy
Interface InterceptorHandler
- All Known Implementing Classes:
DecoratorHandler,DefaultInterceptorHandler
public interface InterceptorHandler
An InterceptorHandler can be used to dynamically invoke methods on
an internally stored target instance.
-
Method Summary
-
Method Details
-
invoke
This method will get called whenever the proxy of the intercepted instance will get invoked.- Parameters:
method- Method which should get invokedargs- original invocation parameters- Returns:
- the return value of the intercepted methos
-