org.apache.webbeans.proxy
Interface OwbNormalScopeProxy

All Superinterfaces:
Serializable

public interface OwbNormalScopeProxy
extends Serializable

Interface for all OpenWebBeans NormalScope Proxies. A normalscoping proxy just resolves the underlying Contextual Instance and directly invokes the target method onto it.

Each OwbNormalScopeProxy contains a Provider which returns the current Contextual Instance.

This interface extends Serializable because every NormalScoped bean proxy must be Serializable!




Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.