|
||||||||||
| PREV NEXT | FRAMES NO FRAMES | |||||||||
| Packages that use AbstractProxyFactory | |
|---|---|
| org.apache.webbeans.proxy | |
| Uses of AbstractProxyFactory in org.apache.webbeans.proxy |
|---|
| Subclasses of AbstractProxyFactory in org.apache.webbeans.proxy | |
|---|---|
class |
InterceptorDecoratorProxyFactory
Generate a dynamic subclass which has exactly 1 delegation point instance which get's set in the Constructor of the proxy. |
class |
NormalScopeProxyFactory
This factory creates proxies which delegate the method invocations 1:1 to an instance which gets resolved via a Provider. |
class |
SubclassProxyFactory
This factory creates subclasses for abstract classes. |
|
||||||||||
| PREV NEXT | FRAMES NO FRAMES | |||||||||