Package org.apache.webbeans.proxy
package org.apache.webbeans.proxy
-
ClassDescriptionBase class for all OWB Proxy factoriesGenerate a dynamic subclass which has exactly 1 delegation point instance which get's set in the Constructor of the proxy.An InterceptorHandler can be used to dynamically invoke methods on an internally stored target instance.This factory creates proxies which delegate the method invocations 1:1 to an instance which gets resolved via a
Provider.Interface for all OpenWebBeans abstract Decorator subclasses.Marker Interface for all OpenWebBeans Interceptor+Decorator Proxies.Interface for all OpenWebBeansNormalScopeProxies.This factory creates subclasses for abstract classes.