Package org.apache.webbeans.proxy

Interface Summary
InterceptorHandler An InterceptorHandler can be used to dynamically invoke methods on an internally stored target instance.
OwbDecoratorProxy Interface for all OpenWebBeans abstract Decorator subclasses.
OwbInterceptorProxy Marker Interface for all OpenWebBeans Interceptor+Decorator Proxies.
OwbNormalScopeProxy Interface for all OpenWebBeans NormalScope Proxies.
 

Class Summary
AbstractProxyFactory Base class for all OWB Proxy factories
InterceptorDecoratorProxyFactory Generate a dynamic subclass which has exactly 1 delegation point instance which get's set in the Constructor of the proxy.
NormalScopeProxyFactory This factory creates proxies which delegate the method invocations 1:1 to an instance which gets resolved via a Provider.
SubclassProxyFactory This factory creates subclasses for abstract classes.
 

Exception Summary
ProxyGenerationException Exceptions which might happen during proxy creation.
 



Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.