Uses of Package
org.apache.webbeans.proxy

Packages that use org.apache.webbeans.proxy
org.apache.webbeans.config   
org.apache.webbeans.intercept   
org.apache.webbeans.portable   
org.apache.webbeans.proxy   
 

Classes in org.apache.webbeans.proxy used by org.apache.webbeans.config
InterceptorDecoratorProxyFactory
          Generate a dynamic subclass which has exactly 1 delegation point instance which get's set in the Constructor of the proxy.
NormalScopeProxyFactory
          This factory creates proxies which delegate the method invocations 1:1 to an instance which gets resolved via a Provider.
SubclassProxyFactory
          This factory creates subclasses for abstract classes.
 

Classes in org.apache.webbeans.proxy used by org.apache.webbeans.intercept
InterceptorHandler
          An InterceptorHandler can be used to dynamically invoke methods on an internally stored target instance.
 

Classes in org.apache.webbeans.proxy used by org.apache.webbeans.portable
InterceptorDecoratorProxyFactory
          Generate a dynamic subclass which has exactly 1 delegation point instance which get's set in the Constructor of the proxy.
 

Classes in org.apache.webbeans.proxy used by org.apache.webbeans.proxy
AbstractProxyFactory
          Base class for all OWB Proxy factories
InterceptorHandler
          An InterceptorHandler can be used to dynamically invoke methods on an internally stored target instance.
OwbInterceptorProxy
          Marker Interface for all OpenWebBeans Interceptor+Decorator Proxies.
OwbNormalScopeProxy
          Interface for all OpenWebBeans NormalScope Proxies.
ProxyGenerationException
          Exceptions which might happen during proxy creation.
 



Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.