|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||
java.lang.Objectorg.apache.webbeans.util.ClassUtil
public final class ClassUtil
Utility classes with respect to the class operations.
| Field Summary | |
|---|---|
static Map<Class<?>,Class<?>> |
PRIMITIVE_TO_WRAPPERS_MAP
|
| Method Summary | |
|---|---|
static Object |
callInstanceMethod(Method method,
Object instance,
Object[] args)
Call method on the instance with given arguments. |
static boolean |
checkBeanAndRequiredTypeIsParametrized(Type beanTypeArg,
Type requiredTypeArg)
Check parametrized bean type and parametrized required types. |
static boolean |
checkBeanTypeAndRequiredIsTypeVariable(Type beanTypeArg,
Type requiredTypeArg)
|
static boolean |
checkEventTypeAssignability(Type eventType,
Type observerType)
Checks that event is applicable for the given observer type. |
static boolean |
checkParametrizedType(ParameterizedType pType)
Return true if it does not contain type variable for wildcard type false otherwise. |
static boolean |
checkRequiredTypeIsClassAndBeanTypeIsVariable(Type beanTypeArg,
Type requiredTypeArg)
Checking bean type and required type. |
static boolean |
checkRequiredTypeIsParameterizedAndBeanTypeIsVariable(Type beanTypeArg,
Type requiredTypeArg)
|
static boolean |
checkRequiredTypeIsTypeVariableAndBeanTypeIsClass(Type beanTypeArg,
Type requiredTypeArg)
|
static boolean |
checkRequiredTypeIsWildCard(Type beanTypeArg,
Type requiredTypeArg)
Check bean type and required type. |
static Type[] |
getActualTypeArguments(Type type)
Returns declared type arguments if type is a
ParameterizedType instance, else an empty array. |
static Class<?> |
getClass(Type type)
Gets the class of the given type arguments. |
static Class<?> |
getClassFromName(String name)
|
static Class<?> |
getClazz(Type type)
Return raw class type for given type. |
static List<Method> |
getNonPrivateMethods(Class<?> topClass,
boolean excludeFinalMethods)
collect all non-private, non-static and non-abstract methods from the given class. |
static Class<?> |
getPrimitiveWrapper(Class<?> clazz)
|
static Class<?> |
getRawTypeForInjectionPoint(InjectionPoint injectionPoint)
Returns injection point raw type. |
static boolean |
isAssignableForParametrized(ParameterizedType beanType,
ParameterizedType requiredType)
Returns true if given bean's api type is injectable to injection point required type. |
static boolean |
isClassAssignable(Class<?> lhs,
Class<?> rhs)
Returns true if rhs is assignable type to the lhs, false otherwise. |
static boolean |
isConcrete(Class<?> clazz)
Returna true if the class is not abstract and interface. |
static boolean |
isDefinitionContainsTypeVariables(Type type)
Learn whether the specified class is defined with type parameters. |
static boolean |
isInnerClazz(Class<?> clazz)
Check the class is inner or not |
static boolean |
isMethodHasCheckedException(Method method)
Check method throws checked exception or not. |
static boolean |
isObjectMethod(String methodName)
Checks if the given method if from Object.class |
static boolean |
isOverridden(List<Method> subclassMethods,
Method superclassMethod)
Check if the method is already defined in a subclass |
static boolean |
isOverridden(Method subClassMethod,
Method superClassMethod)
Check whether superClassMethod is overridden by subClassMethod. |
static boolean |
isParametrizedType(Type type)
Returns true if type is an instance of ParameterizedType
else otherwise. |
static boolean |
isSame(Type type1,
Type type2)
|
static boolean |
isTypeVariable(Type type)
Returns true if type is an instance of TypeVariable
else otherwise. |
static boolean |
isUnboundedTypeVariable(Type type)
|
static boolean |
isWildCardType(Type type)
Returns true if type is an instance of WildcardType
else otherwise. |
| Methods inherited from class java.lang.Object |
|---|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
| Field Detail |
|---|
public static final Map<Class<?>,Class<?>> PRIMITIVE_TO_WRAPPERS_MAP
| Method Detail |
|---|
public static Class<?> getClassFromName(String name)
public static boolean isInnerClazz(Class<?> clazz)
clazz - to check
public static boolean isSame(Type type1,
Type type2)
public static Class<?> getPrimitiveWrapper(Class<?> clazz)
public static Class<?> getClass(Type type)
If the given type Type parameters is an instance of the
ParameterizedType, it returns the raw type otherwise it return
the casted Class of the type argument.
type - class or parametrized type
public static boolean isMethodHasCheckedException(Method method)
method - method instance
public static Object callInstanceMethod(Method method,
Object instance,
Object[] args)
method - method instanceinstance - object instanceargs - arguments
public static List<Method> getNonPrivateMethods(Class<?> topClass,
boolean excludeFinalMethods)
Object.finalize() method as users must not deal with it.
topClass - the class to start with. Then move up the hierarchyexcludeFinalMethods - whether final classes should get excluded from the result
public static boolean isOverridden(List<Method> subclassMethods,
Method superclassMethod)
subclassMethods - superclassMethod - public static boolean isObjectMethod(String methodName)
methodName -
true if the given method is from Object.class (either directly or overloaded)public static boolean isParametrizedType(Type type)
ParameterizedType
else otherwise.
type - type of the artifact
ParameterizedTypepublic static boolean isWildCardType(Type type)
WildcardType
else otherwise.
type - type of the artifact
WildcardTypepublic static boolean isUnboundedTypeVariable(Type type)
public static boolean isTypeVariable(Type type)
TypeVariable
else otherwise.
type - type of the artifact
TypeVariablepublic static boolean isConcrete(Class<?> clazz)
clazz - class type
public static boolean checkEventTypeAssignability(Type eventType,
Type observerType)
eventType - event typeobserverType - observer type
public static boolean isClassAssignable(Class<?> lhs,
Class<?> rhs)
lhs - left hand side classrhs - right hand side class
public static boolean isAssignableForParametrized(ParameterizedType beanType,
ParameterizedType requiredType)
beanType - bean parametrized api typerequiredType - injection point parametrized api type
public static boolean checkBeanAndRequiredTypeIsParametrized(Type beanTypeArg,
Type requiredTypeArg)
beanTypeArg - parametrized bean typerequiredTypeArg - parametrized required type
public static boolean checkRequiredTypeIsWildCard(Type beanTypeArg,
Type requiredTypeArg)
Required type is a wildcard type.
beanTypeArg - bean typerequiredTypeArg - required type
public static boolean checkRequiredTypeIsClassAndBeanTypeIsVariable(Type beanTypeArg,
Type requiredTypeArg)
Required type is class and bean type is a type variable.
beanTypeArg - bean typerequiredTypeArg - required type
public static boolean checkRequiredTypeIsParameterizedAndBeanTypeIsVariable(Type beanTypeArg,
Type requiredTypeArg)
public static boolean checkRequiredTypeIsTypeVariableAndBeanTypeIsClass(Type beanTypeArg,
Type requiredTypeArg)
public static boolean checkBeanTypeAndRequiredIsTypeVariable(Type beanTypeArg,
Type requiredTypeArg)
public static boolean isDefinitionContainsTypeVariables(Type type)
type - to check
public static Type[] getActualTypeArguments(Type type)
type is a
ParameterizedType instance, else an empty array.
Get the actual type arguments of a type.
type -
public static Class<?> getClazz(Type type)
type - base type instance
public static boolean checkParametrizedType(ParameterizedType pType)
pType - parameterized type
public static Class<?> getRawTypeForInjectionPoint(InjectionPoint injectionPoint)
injectionPoint - injection point definition
public static boolean isOverridden(Method subClassMethod,
Method superClassMethod)
superClassMethod is overridden by subClassMethod.
subClassMethod - potentially overridingsuperClassMethod - potentially overridden
|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||