org.apache.webbeans.util
Class GenericsUtil

java.lang.Object
  extended by org.apache.webbeans.util.GenericsUtil

public final class GenericsUtil
extends Object

Utility classes for generic type operations.


Constructor Summary
GenericsUtil()
           
 
Method Summary
static Set<Type> getTypeClosure(Type type, Class<?> owningClass, Class<?> declaringClass)
           
static boolean isAssignableFrom(boolean isDelegate, Type requiredType, Type beanType)
          5.2.3 and 5.2.4
static Type[] resolveParameterTypes(Class<?> subclass, Constructor<?> constructor)
          Resolves the actual parameter types of the specified constructor for the type hierarchy specified by the given subclass
static Type[] resolveParameterTypes(Class<?> subclass, Method method)
          Resolves the actual parameter types of the specified method for the type hierarchy specified by the given subclass
static Type resolveReturnType(Class<?> subclass, Method method)
          Resolves the actual return type of the specified method for the type hierarchy specified by the given subclass
static Type resolveType(Class<?> subclass, Field field)
          Resolves the actual type of the specified field for the type hierarchy specified by the given subclass
static Type resolveType(Type type, Class<?> subclass, Member member)
          Resolves the actual type of the specified type for the type hierarchy specified by the given subclass
static Type[] resolveTypes(Type[] types, org.apache.webbeans.util.GenericsUtil.TypeVariableResolver resolution)
           
static boolean satisfiesDependency(boolean isDelegate, Type injectionPointType, Type beanType)
           
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 

Constructor Detail

GenericsUtil

public GenericsUtil()
Method Detail

satisfiesDependency

public static boolean satisfiesDependency(boolean isDelegate,
                                          Type injectionPointType,
                                          Type beanType)

isAssignableFrom

public static boolean isAssignableFrom(boolean isDelegate,
                                       Type requiredType,
                                       Type beanType)
5.2.3 and 5.2.4


resolveType

public static Type resolveType(Class<?> subclass,
                               Field field)
Resolves the actual type of the specified field for the type hierarchy specified by the given subclass


resolveReturnType

public static Type resolveReturnType(Class<?> subclass,
                                     Method method)
Resolves the actual return type of the specified method for the type hierarchy specified by the given subclass


resolveParameterTypes

public static Type[] resolveParameterTypes(Class<?> subclass,
                                           Constructor<?> constructor)
Resolves the actual parameter types of the specified constructor for the type hierarchy specified by the given subclass


resolveParameterTypes

public static Type[] resolveParameterTypes(Class<?> subclass,
                                           Method method)
Resolves the actual parameter types of the specified method for the type hierarchy specified by the given subclass


resolveType

public static Type resolveType(Type type,
                               Class<?> subclass,
                               Member member)
Resolves the actual type of the specified type for the type hierarchy specified by the given subclass


resolveTypes

public static Type[] resolveTypes(Type[] types,
                                  org.apache.webbeans.util.GenericsUtil.TypeVariableResolver resolution)

getTypeClosure

public static Set<Type> getTypeClosure(Type type,
                                       Class<?> owningClass,
                                       Class<?> declaringClass)


Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.