|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||
java.lang.Objectorg.apache.webbeans.util.GenericsUtil
public final class GenericsUtil
Utility classes for generic type operations.
| Constructor Summary | |
|---|---|
GenericsUtil()
|
|
| Method Summary | |
|---|---|
static Set<Type> |
getTypeClosure(Type type,
Class<?> owningClass,
Class<?> declaringClass)
|
static boolean |
isAssignableFrom(boolean isDelegate,
Type requiredType,
Type beanType)
5.2.3 and 5.2.4 |
static Type[] |
resolveParameterTypes(Class<?> subclass,
Constructor<?> constructor)
Resolves the actual parameter types of the specified constructor for the type hierarchy specified by the given subclass |
static Type[] |
resolveParameterTypes(Class<?> subclass,
Method method)
Resolves the actual parameter types of the specified method for the type hierarchy specified by the given subclass |
static Type |
resolveReturnType(Class<?> subclass,
Method method)
Resolves the actual return type of the specified method for the type hierarchy specified by the given subclass |
static Type |
resolveType(Class<?> subclass,
Field field)
Resolves the actual type of the specified field for the type hierarchy specified by the given subclass |
static Type |
resolveType(Type type,
Class<?> subclass,
Member member)
Resolves the actual type of the specified type for the type hierarchy specified by the given subclass |
static Type[] |
resolveTypes(Type[] types,
org.apache.webbeans.util.GenericsUtil.TypeVariableResolver resolution)
|
static boolean |
satisfiesDependency(boolean isDelegate,
Type injectionPointType,
Type beanType)
|
| Methods inherited from class java.lang.Object |
|---|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
| Constructor Detail |
|---|
public GenericsUtil()
| Method Detail |
|---|
public static boolean satisfiesDependency(boolean isDelegate,
Type injectionPointType,
Type beanType)
public static boolean isAssignableFrom(boolean isDelegate,
Type requiredType,
Type beanType)
public static Type resolveType(Class<?> subclass,
Field field)
public static Type resolveReturnType(Class<?> subclass,
Method method)
public static Type[] resolveParameterTypes(Class<?> subclass,
Constructor<?> constructor)
public static Type[] resolveParameterTypes(Class<?> subclass,
Method method)
public static Type resolveType(Type type,
Class<?> subclass,
Member member)
public static Type[] resolveTypes(Type[] types,
org.apache.webbeans.util.GenericsUtil.TypeVariableResolver resolution)
public static Set<Type> getTypeClosure(Type type,
Class<?> owningClass,
Class<?> declaringClass)
|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||