Package org.apache.webbeans.util
Class StringUtil
java.lang.Object
org.apache.webbeans.util.StringUtil
a few static string utility methods
-
Method Summary
-
Method Details
-
isEmpty
- Returns:
trueif the given string is eithernullor an empty string
-
isNotEmpty
- Returns:
trueif the given string is not null and has a content
-
isBlank
- Returns:
trueif the given string is eithernullor an empty or blank string
-