org.apache.webbeans.util
Class StringUtil

java.lang.Object
  extended by org.apache.webbeans.util.StringUtil

public final class StringUtil
extends Object

a few static string utility methods


Method Summary
static boolean isBlank(String val)
           
static boolean isEmpty(String val)
           
static boolean isNotEmpty(String val)
           
 
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
 

Method Detail

isEmpty

public static boolean isEmpty(String val)
Returns:
true if the given string is either null or an empty string

isNotEmpty

public static boolean isNotEmpty(String val)
Returns:
true if the given string is not null and has a content

isBlank

public static boolean isBlank(String val)
Returns:
true if the given string is either null or an empty or blank string


Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.