org.apache.webbeans.util
Class StringUtil
java.lang.Object
org.apache.webbeans.util.StringUtil
public final class StringUtil
- extends Object
a few static string utility methods
| Methods inherited from class java.lang.Object |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
isEmpty
public static boolean isEmpty(String val)
- Returns:
true if the given string is either null or an empty string
isNotEmpty
public static boolean isNotEmpty(String val)
- Returns:
true if the given string is not null and has a content
isBlank
public static boolean isBlank(String val)
- Returns:
true if the given string is either null or an empty or blank string
Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.