|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||
java.lang.Objectorg.apache.webbeans.xml.DefaultBeanArchiveService
public class DefaultBeanArchiveService
Please note that this implementation is not thread safe.
| Nested Class Summary |
|---|
| Nested classes/interfaces inherited from interface org.apache.webbeans.spi.BeanArchiveService |
|---|
BeanArchiveService.BeanArchiveInformation, BeanArchiveService.BeanDiscoveryMode |
| Constructor Summary | |
|---|---|
DefaultBeanArchiveService()
|
|
| Method Summary | |
|---|---|
protected DefaultBeanArchiveInformation |
createBeanArchiveInformation()
This method exists for extensibility reasons. |
BeanArchiveService.BeanArchiveInformation |
getBeanArchiveInformation(URL beanArchiveUrl)
|
protected Element |
getBeansRootElement(InputStream xmlStream)
Gets the root element of the parsed document. |
Set<URL> |
getRegisteredBeanArchives()
|
protected String |
getTrimmedAttribute(Element element,
String attributeName)
|
protected BeanArchiveService.BeanArchiveInformation |
readBeansXml(InputStream xmlStreamIn)
Read the information from the given beans.xml and fill it into a BeanArchiveInformation instance. |
void |
release()
|
protected String |
stripProtocol(String urlPath)
Get rid of any protocol header from the url externalForm |
| Methods inherited from class java.lang.Object |
|---|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
| Constructor Detail |
|---|
public DefaultBeanArchiveService()
| Method Detail |
|---|
public BeanArchiveService.BeanArchiveInformation getBeanArchiveInformation(URL beanArchiveUrl)
getBeanArchiveInformation in interface BeanArchiveServicepublic Set<URL> getRegisteredBeanArchives()
getRegisteredBeanArchives in interface BeanArchiveServiceprotected DefaultBeanArchiveInformation createBeanArchiveInformation()
protected String stripProtocol(String urlPath)
urlPath -
protected BeanArchiveService.BeanArchiveInformation readBeansXml(InputStream xmlStreamIn)
throws IOException
IOExceptionpublic void release()
release in interface BeanArchiveService
protected Element getBeansRootElement(InputStream xmlStream)
throws WebBeansException
xmlStream - parsed document
WebBeansException - if any runtime exception occurs
protected String getTrimmedAttribute(Element element,
String attributeName)
null if the attribute does not exist or the attribute is empty
|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||