Serialized Form


Package org.apache.webbeans.annotation

Class org.apache.webbeans.annotation.AnyLiteral extends EmptyAnnotationLiteral<javax.enterprise.inject.Any> implements Serializable

serialVersionUID: -8922048102786275371L

Class org.apache.webbeans.annotation.ApplicationScopeLiteral extends javax.enterprise.util.AnnotationLiteral<javax.enterprise.context.ApplicationScoped> implements Serializable

serialVersionUID: 8089948111744513390L

Class org.apache.webbeans.annotation.DefaultLiteral extends EmptyAnnotationLiteral<javax.enterprise.inject.Default> implements Serializable

serialVersionUID: 6788272256977634238L

Class org.apache.webbeans.annotation.DependentScopeLiteral extends javax.enterprise.util.AnnotationLiteral<javax.enterprise.context.Dependent> implements Serializable

serialVersionUID: -2677299920840834714L

Class org.apache.webbeans.annotation.DestroyedLiteral extends javax.enterprise.util.AnnotationLiteral<javax.enterprise.context.Destroyed> implements Serializable

serialVersionUID: 8867272511520063730L

Serialized Fields

value

Class<T> value

Class org.apache.webbeans.annotation.EmptyAnnotationLiteral extends javax.enterprise.util.AnnotationLiteral<T extends Annotation> implements Serializable

Serialized Fields

annotationType

Class<T> annotationType

Class org.apache.webbeans.annotation.InitializedLiteral extends javax.enterprise.util.AnnotationLiteral<javax.enterprise.context.Initialized> implements Serializable

serialVersionUID: 8867272511520063730L

Serialized Fields

value

Class<T> value

Class org.apache.webbeans.annotation.NamedLiteral extends javax.enterprise.util.AnnotationLiteral<javax.inject.Named> implements Serializable

serialVersionUID: 8867272511520063730L

Serialized Fields

value

String value

Class org.apache.webbeans.annotation.NewLiteral extends javax.enterprise.util.AnnotationLiteral<javax.enterprise.inject.New> implements Serializable

serialVersionUID: -2981014729208063412L

Serialized Fields

clazz

Class<T> clazz

Class org.apache.webbeans.annotation.RequestedScopeLiteral extends EmptyAnnotationLiteral<javax.enterprise.context.RequestScoped> implements Serializable

serialVersionUID: -7333612898060695008L

Class org.apache.webbeans.annotation.SessionScopeLiteral extends EmptyAnnotationLiteral<javax.enterprise.context.SessionScoped> implements Serializable

serialVersionUID: -7469945140661485990L


Package org.apache.webbeans.component

Class org.apache.webbeans.component.CdiInterceptorBean extends InterceptorBean<T> implements Serializable

Serialized Fields

interceptorBindings

Set<E> interceptorBindings

Class org.apache.webbeans.component.DecoratorBean extends InjectionTargetBean<T> implements Serializable

Serialized Fields

decoratedTypes

Set<E> decoratedTypes
The Types the decorator itself implements


delegateType

Type delegateType
The Type of the @Delegate injection point.


delegateQualifiers

Set<E> delegateQualifiers
The Qualifiers of the @Delegate injection point.

Class org.apache.webbeans.component.EjbInterceptorBean extends InterceptorBean<T> implements Serializable

Class org.apache.webbeans.component.InjectionTargetBean extends AbstractOwbBean<T> implements Serializable

Serialization Methods

writeReplace

private Object writeReplace()
                     throws ObjectStreamException
This uses the PassivationBeanWrapper to only store the beanPassivationId.

Throws:
ObjectStreamException
Serialized Fields

annotatedType

javax.enterprise.inject.spi.AnnotatedType<X> annotatedType
Annotated type for bean


injectionTarget

javax.enterprise.inject.spi.InjectionTarget<T> injectionTarget

Class org.apache.webbeans.component.InterceptorBean extends InjectionTargetBean<T> implements Serializable

Serialized Fields

interceptionMethods

Map<K,V> interceptionMethods
The Methods to be called per interception type. The method signature must be
Object (InvocationContext) throws Exception


aroundInvokeMethod

Method aroundInvokeMethod
This is for performance reasons

Class org.apache.webbeans.component.ManagedBean extends InjectionTargetBean<T> implements Serializable

Serialized Fields

originalInjectionTarget

InjectionTargetImpl<T> originalInjectionTarget

Class org.apache.webbeans.component.NewManagedBean extends ManagedBean<T> implements Serializable

Class org.apache.webbeans.component.PrincipalProvider extends Object implements Serializable

Serialization Methods

readResolve

Object readResolve()
             throws ObjectStreamException
Throws:
ObjectStreamException

Class org.apache.webbeans.component.ProducerAwareInjectionTargetBean extends AbstractOwbBean<T> implements Serializable

Serialization Methods

writeReplace

private Object writeReplace()
                     throws ObjectStreamException
Throws:
ObjectStreamException
Serialized Fields

producer

javax.enterprise.inject.spi.Producer<T> producer

Class org.apache.webbeans.component.ResourceProvider extends Object implements Serializable

Serialization Methods

readResolve

Object readResolve()
             throws ObjectStreamException
Throws:
ObjectStreamException
Serialized Fields

resourceReference

ResourceReference<X,T extends Annotation> resourceReference

Class org.apache.webbeans.component.SelfInterceptorBean extends InterceptorBean<T> implements Serializable


Package org.apache.webbeans.container

Class org.apache.webbeans.container.InjectableBeanManager extends Object implements Serializable

serialVersionUID: 1L

Serialization Methods

readExternal

public void readExternal(ObjectInput in)
                  throws IOException,
                         ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeExternal

public void writeExternal(ObjectOutput out)
                   throws IOException
Throws:
IOException

Class org.apache.webbeans.container.SerializableBean extends Object implements Serializable

serialVersionUID: -8141263188006177021L

Serialization Methods

readObject

private void readObject(ObjectInputStream s)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream s)
                  throws IOException
Throws:
IOException
Serialized Fields

bean

javax.enterprise.inject.spi.Bean<T> bean
the delegated bean


Package org.apache.webbeans.context

Class org.apache.webbeans.context.AbstractContext extends Object implements Serializable

serialVersionUID: 2357678967444477818L

Serialization Methods

readObject

private void readObject(ObjectInputStream s)
                 throws IOException,
                        ClassNotFoundException
Read object.

Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream s)
                  throws IOException
Write Object.

Throws:
IOException
Serialized Fields

active

boolean active
Context status, active or not


componentInstanceMap

Map<K,V> componentInstanceMap
Context contextual instances


scopeType

Class<T> scopeType
Contextual Scope Type

Class org.apache.webbeans.context.ApplicationContext extends AbstractContext implements Serializable

serialVersionUID: -8254441824647652312L

Serialized Fields

destroyed

boolean destroyed
used to prevent us firing the Destroyed event twice. We cannot just use setActive(false) as this would trash @BeforeShutdown

Class org.apache.webbeans.context.ConversationContext extends PassivatingContext implements Serializable

serialVersionUID: 2L

Serialization Methods

readExternal

public void readExternal(ObjectInput in)
                  throws IOException,
                         ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeExternal

public void writeExternal(ObjectOutput out)
                   throws IOException
Throws:
IOException

Class org.apache.webbeans.context.DependentContext extends AbstractContext implements Serializable

serialVersionUID: 8225241216057316441L

Class org.apache.webbeans.context.PassivatingContext extends AbstractContext implements Serializable

Serialization Methods

readExternal

public void readExternal(ObjectInput in)
                  throws IOException,
                         ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeExternal

public void writeExternal(ObjectOutput out)
                   throws IOException
Throws:
IOException

Class org.apache.webbeans.context.RequestContext extends AbstractContext implements Serializable

serialVersionUID: -1030240915163272268L

Serialized Fields

propagatedSessionContext

SessionContext propagatedSessionContext
If a Session gets destroyed in a HttpRequest then we store the session away and only destroy it at the end of the request.

Class org.apache.webbeans.context.SessionContext extends PassivatingContext implements Serializable

serialVersionUID: 2L

Serialization Methods

readExternal

public void readExternal(ObjectInput in)
                  throws IOException,
                         ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeExternal

public void writeExternal(ObjectOutput out)
                   throws IOException
Throws:
IOException

Class org.apache.webbeans.context.SingletonContext extends AbstractContext implements Serializable

serialVersionUID: -7600942820719243149L


Package org.apache.webbeans.context.creational

Class org.apache.webbeans.context.creational.BeanInstanceBag extends Object implements Serializable

serialVersionUID: 1656996021599122499L

Serialized Fields

beanCreationalContext

javax.enterprise.context.spi.CreationalContext<T> beanCreationalContext

beanInstance

Object beanInstance

lock

Lock lock

Class org.apache.webbeans.context.creational.CreationalContextImpl extends Object implements Serializable

serialVersionUID: 1L

Serialization Methods

readObject

private void readObject(ObjectInputStream s)
                 throws IOException,
                        ClassNotFoundException
Read object.

Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream s)
                  throws IOException
Write Object.

Throws:
IOException
Serialized Fields

dependentObjects

List<E> dependentObjects
Contextual bean dependent instances

ATTENTION This variable gets initiated lazily!


bean

javax.enterprise.inject.spi.Bean<T> bean
Contains the currently created bean


contextual

javax.enterprise.context.spi.Contextual<T> contextual
Contains the currently created contextual, may be a bean, interceptor or decorator


webBeansContext

WebBeansContext webBeansContext

destroying

boolean destroying
This flag will get set to true to prevent recursive loops while destroying the CreationContext.

Class org.apache.webbeans.context.creational.DependentCreationalContext extends Object implements Serializable

serialVersionUID: 1L

Serialization Methods

readObject

private void readObject(ObjectInputStream s)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream s)
                  throws IOException
Throws:
IOException
Serialized Fields

contextual

javax.enterprise.context.spi.Contextual<T> contextual

instance

Object instance

Package org.apache.webbeans.conversation

Class org.apache.webbeans.conversation.ConversationImpl extends Object implements Serializable

serialVersionUID: 8511063860333431722L

Serialization Methods

readObject

private void readObject(ObjectInputStream in)
                 throws IOException,
                        ClassNotFoundException
Initialize a few fields on deserialisation

Throws:
IOException
ClassNotFoundException
Serialized Fields

id

String id
Conversation id


isTransient

boolean isTransient
Transient or not. Transient conversations are destroyed at the end of the request


timeout

long timeout
Default timeout is 30mins


lastAccessTime

long lastAccessTime
Active duration of the conversation

Class org.apache.webbeans.conversation.ConversationStorageBean extends Object implements Serializable


Package org.apache.webbeans.event

Class org.apache.webbeans.event.EventImpl extends Object implements Serializable

serialVersionUID: 393021493190378023L

Serialization Methods

readObject

private void readObject(ObjectInputStream in)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException
Serialized Fields

metadata

EventMetadataImpl metadata

Class org.apache.webbeans.event.EventMetadataImpl extends Object implements Serializable

serialVersionUID: -6401875861180683988L

Serialization Methods

readObject

private void readObject(ObjectInputStream in)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException
Serialized Fields

type

Type type

selectType

Type selectType

injectionPoint

javax.enterprise.inject.spi.InjectionPoint injectionPoint

qualifiers

Set<E> qualifiers

Package org.apache.webbeans.exception

Class org.apache.webbeans.exception.DuplicateDefinitionException extends javax.enterprise.inject.spi.DefinitionException implements Serializable

serialVersionUID: 2312285271502063304L

Serialized Fields

msg

ExceptionMessageBuilder msg

Class org.apache.webbeans.exception.InconsistentSpecializationException extends javax.enterprise.inject.spi.DefinitionException implements Serializable

serialVersionUID: 5398575103682514128L

Serialized Fields

msg

ExceptionMessageBuilder msg

Class org.apache.webbeans.exception.ProxyGenerationException extends RuntimeException implements Serializable

Serialized Fields

msg

ExceptionMessageBuilder msg

Class org.apache.webbeans.exception.WebBeansConfigurationException extends javax.enterprise.inject.spi.DefinitionException implements Serializable

serialVersionUID: 1863095663133791175L

Serialized Fields

msg

ExceptionMessageBuilder msg

Class org.apache.webbeans.exception.WebBeansCreationException extends WebBeansException implements Serializable

serialVersionUID: 1863095663133791175L

Serialized Fields

msg

ExceptionMessageBuilder msg

Class org.apache.webbeans.exception.WebBeansDeploymentException extends javax.enterprise.inject.spi.DeploymentException implements Serializable

serialVersionUID: 1863095663133791175L

Serialized Fields

msg

ExceptionMessageBuilder msg

Class org.apache.webbeans.exception.WebBeansException extends RuntimeException implements Serializable

serialVersionUID: -3721839220664165557L

Serialized Fields

cause

Throwable cause

msg

ExceptionMessageBuilder msg

Package org.apache.webbeans.exception.helper

Class org.apache.webbeans.exception.helper.ExceptionMessageBuilder extends Object implements Serializable

serialVersionUID: 4391880458753108617L

Serialized Fields

additionalInformations

List<E> additionalInformations

Package org.apache.webbeans.inject.instance

Class org.apache.webbeans.inject.instance.InstanceImpl extends Object implements Serializable

serialVersionUID: -8401944412490389024L

Serialization Methods

readObject

private void readObject(ObjectInputStream in)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream op)
                  throws IOException
Throws:
IOException
Serialized Fields

injectionClazz

Type injectionClazz
Injected class type


injectionPoint

javax.enterprise.inject.spi.InjectionPoint injectionPoint
injection point, needed for injection into producer method and used to determine the BDA it was loaded from or null.


qualifierAnnotations

Set<E> qualifierAnnotations
Qualifier annotations appeared on the injection point


webBeansContext

WebBeansContext webBeansContext

creationalContexts

Map<K,V> creationalContexts

parentCreationalContext

CreationalContextImpl<T> parentCreationalContext

Package org.apache.webbeans.intercept

Class org.apache.webbeans.intercept.ApplicationScopedBeanInterceptorHandler extends NormalScopedBeanInterceptorHandler implements Serializable

serialVersionUID: 1L

Class org.apache.webbeans.intercept.DecoratorHandler extends Object implements Serializable

Serialization Methods

readExternal

public void readExternal(ObjectInput in)
                  throws IOException,
                         ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeExternal

public void writeExternal(ObjectOutput out)
                   throws IOException
Throws:
IOException

Class org.apache.webbeans.intercept.DefaultInterceptorHandler extends Object implements Serializable

Serialization Methods

readExternal

public void readExternal(ObjectInput in)
                  throws IOException,
                         ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeExternal

public void writeExternal(ObjectOutput out)
                   throws IOException
Throws:
IOException

Class org.apache.webbeans.intercept.NormalScopedBeanInterceptorHandler extends Object implements Serializable

Serialization Methods

readResolve

protected Object readResolve()
                      throws ObjectStreamException
The following code gets generated into the proxy:
 Object writeReplace() throws ObjectStreamException
 {
     return provider;
 }
 

Throws:
ObjectStreamException
Serialized Fields

beanPassivationId

String beanPassivationId
The passivation if in case this is a PassivationCapable bean. we just keep this field for serializing it away

Class org.apache.webbeans.intercept.RequestScopedBeanInterceptorHandler extends NormalScopedBeanInterceptorHandler implements Serializable

serialVersionUID: 1L

Class org.apache.webbeans.intercept.SessionScopedBeanInterceptorHandler extends NormalScopedBeanInterceptorHandler implements Serializable

serialVersionUID: 1L


Package org.apache.webbeans.proxy



Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.