Serialized Form
|
Package org.apache.webbeans.annotation |
serialVersionUID: -8922048102786275371L
serialVersionUID: 8089948111744513390L
serialVersionUID: 6788272256977634238L
serialVersionUID: -2677299920840834714L
serialVersionUID: 8867272511520063730L
value
Class<T> value
annotationType
Class<T> annotationType
serialVersionUID: 8867272511520063730L
value
Class<T> value
serialVersionUID: 8867272511520063730L
value
String value
serialVersionUID: -2981014729208063412L
clazz
Class<T> clazz
serialVersionUID: -7333612898060695008L
serialVersionUID: -7469945140661485990L
|
Package org.apache.webbeans.component |
interceptorBindings
Set<E> interceptorBindings
decoratedTypes
Set<E> decoratedTypes
- The Types the decorator itself implements
delegateType
Type delegateType
- The Type of the @Delegate injection point.
delegateQualifiers
Set<E> delegateQualifiers
- The Qualifiers of the @Delegate injection point.
writeReplace
private Object writeReplace()
throws ObjectStreamException
- This uses the
PassivationBeanWrapper
to only store the beanPassivationId.
- Throws:
ObjectStreamException
annotatedType
javax.enterprise.inject.spi.AnnotatedType<X> annotatedType
- Annotated type for bean
injectionTarget
javax.enterprise.inject.spi.InjectionTarget<T> injectionTarget
interceptionMethods
Map<K,V> interceptionMethods
- The Methods to be called per interception type.
The method signature must be
Object (InvocationContext) throws Exception
aroundInvokeMethod
Method aroundInvokeMethod
- This is for performance reasons
originalInjectionTarget
InjectionTargetImpl<T> originalInjectionTarget
readResolve
Object readResolve()
throws ObjectStreamException
- Throws:
ObjectStreamException
writeReplace
private Object writeReplace()
throws ObjectStreamException
- Throws:
ObjectStreamException
producer
javax.enterprise.inject.spi.Producer<T> producer
readResolve
Object readResolve()
throws ObjectStreamException
- Throws:
ObjectStreamException
resourceReference
ResourceReference<X,T extends Annotation> resourceReference
|
Package org.apache.webbeans.container |
serialVersionUID: 1L
readExternal
public void readExternal(ObjectInput in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeExternal
public void writeExternal(ObjectOutput out)
throws IOException
- Throws:
IOException
serialVersionUID: -8141263188006177021L
readObject
private void readObject(ObjectInputStream s)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream s)
throws IOException
- Throws:
IOException
bean
javax.enterprise.inject.spi.Bean<T> bean
- the delegated bean
|
Package org.apache.webbeans.context |
serialVersionUID: 2357678967444477818L
readObject
private void readObject(ObjectInputStream s)
throws IOException,
ClassNotFoundException
- Read object.
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream s)
throws IOException
- Write Object.
- Throws:
IOException
active
boolean active
- Context status, active or not
componentInstanceMap
Map<K,V> componentInstanceMap
- Context contextual instances
scopeType
Class<T> scopeType
- Contextual Scope Type
serialVersionUID: -8254441824647652312L
destroyed
boolean destroyed
- used to prevent us firing the Destroyed event twice.
We cannot just use setActive(false) as this would trash @BeforeShutdown
serialVersionUID: 2L
readExternal
public void readExternal(ObjectInput in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeExternal
public void writeExternal(ObjectOutput out)
throws IOException
- Throws:
IOException
serialVersionUID: 8225241216057316441L
readExternal
public void readExternal(ObjectInput in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeExternal
public void writeExternal(ObjectOutput out)
throws IOException
- Throws:
IOException
serialVersionUID: -1030240915163272268L
propagatedSessionContext
SessionContext propagatedSessionContext
- If a Session gets destroyed in a HttpRequest then we store the session away
and only destroy it at the end of the request.
serialVersionUID: 2L
readExternal
public void readExternal(ObjectInput in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeExternal
public void writeExternal(ObjectOutput out)
throws IOException
- Throws:
IOException
serialVersionUID: -7600942820719243149L
|
Package org.apache.webbeans.context.creational |
serialVersionUID: 1656996021599122499L
beanCreationalContext
javax.enterprise.context.spi.CreationalContext<T> beanCreationalContext
beanInstance
Object beanInstance
lock
Lock lock
serialVersionUID: 1L
readObject
private void readObject(ObjectInputStream s)
throws IOException,
ClassNotFoundException
- Read object.
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream s)
throws IOException
- Write Object.
- Throws:
IOException
dependentObjects
List<E> dependentObjects
- Contextual bean dependent instances
ATTENTION This variable gets initiated lazily!
bean
javax.enterprise.inject.spi.Bean<T> bean
- Contains the currently created bean
contextual
javax.enterprise.context.spi.Contextual<T> contextual
- Contains the currently created contextual, may be a bean, interceptor or decorator
webBeansContext
WebBeansContext webBeansContext
destroying
boolean destroying
- This flag will get set to
true to prevent recursive loops while destroying
the CreationContext.
serialVersionUID: 1L
readObject
private void readObject(ObjectInputStream s)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream s)
throws IOException
- Throws:
IOException
contextual
javax.enterprise.context.spi.Contextual<T> contextual
instance
Object instance
|
Package org.apache.webbeans.conversation |
serialVersionUID: 8511063860333431722L
readObject
private void readObject(ObjectInputStream in)
throws IOException,
ClassNotFoundException
- Initialize a few fields on deserialisation
- Throws:
IOException
ClassNotFoundException
id
String id
- Conversation id
isTransient
boolean isTransient
- Transient or not. Transient conversations are destroyed at the end of the request
timeout
long timeout
- Default timeout is 30mins
lastAccessTime
long lastAccessTime
- Active duration of the conversation
|
Package org.apache.webbeans.event |
serialVersionUID: 393021493190378023L
readObject
private void readObject(ObjectInputStream in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
metadata
EventMetadataImpl metadata
serialVersionUID: -6401875861180683988L
readObject
private void readObject(ObjectInputStream in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
type
Type type
selectType
Type selectType
injectionPoint
javax.enterprise.inject.spi.InjectionPoint injectionPoint
qualifiers
Set<E> qualifiers
|
Package org.apache.webbeans.exception |
serialVersionUID: 2312285271502063304L
msg
ExceptionMessageBuilder msg
serialVersionUID: 5398575103682514128L
msg
ExceptionMessageBuilder msg
msg
ExceptionMessageBuilder msg
serialVersionUID: 1863095663133791175L
msg
ExceptionMessageBuilder msg
serialVersionUID: 1863095663133791175L
msg
ExceptionMessageBuilder msg
serialVersionUID: 1863095663133791175L
msg
ExceptionMessageBuilder msg
serialVersionUID: -3721839220664165557L
cause
Throwable cause
msg
ExceptionMessageBuilder msg
|
Package org.apache.webbeans.exception.helper |
serialVersionUID: 4391880458753108617L
additionalInformations
List<E> additionalInformations
|
Package org.apache.webbeans.inject.instance |
serialVersionUID: -8401944412490389024L
readObject
private void readObject(ObjectInputStream in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream op)
throws IOException
- Throws:
IOException
injectionClazz
Type injectionClazz
- Injected class type
injectionPoint
javax.enterprise.inject.spi.InjectionPoint injectionPoint
- injection point, needed for injection into producer method and used to determine the BDA it was loaded from or null.
qualifierAnnotations
Set<E> qualifierAnnotations
- Qualifier annotations appeared on the injection point
webBeansContext
WebBeansContext webBeansContext
creationalContexts
Map<K,V> creationalContexts
parentCreationalContext
CreationalContextImpl<T> parentCreationalContext
|
Package org.apache.webbeans.intercept |
serialVersionUID: 1L
readExternal
public void readExternal(ObjectInput in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeExternal
public void writeExternal(ObjectOutput out)
throws IOException
- Throws:
IOException
readExternal
public void readExternal(ObjectInput in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeExternal
public void writeExternal(ObjectOutput out)
throws IOException
- Throws:
IOException
readResolve
protected Object readResolve()
throws ObjectStreamException
- The following code gets generated into the proxy:
Object writeReplace() throws ObjectStreamException
{
return provider;
}
- Throws:
ObjectStreamException
beanPassivationId
String beanPassivationId
- The passivation if in case this is a
PassivationCapable bean.
we just keep this field for serializing it away
serialVersionUID: 1L
serialVersionUID: 1L
|
Package org.apache.webbeans.proxy |
Copyright © 2008–2015 The Apache Software Foundation. All rights reserved.