Serialized Form


Package org.apache.webbeans.annotation

Class org.apache.webbeans.annotation.AnyLiteral extends EmptyAnnotationLiteral<Any> implements Serializable

serialVersionUID: -8922048102786275371L

Class org.apache.webbeans.annotation.ApplicationScopeLiteral extends AnnotationLiteral<ApplicationScoped> implements Serializable

serialVersionUID: 8089948111744513390L

Class org.apache.webbeans.annotation.DefaultLiteral extends EmptyAnnotationLiteral<Default> implements Serializable

serialVersionUID: 6788272256977634238L

Class org.apache.webbeans.annotation.DependentScopeLiteral extends AnnotationLiteral<Dependent> implements Serializable

serialVersionUID: -2677299920840834714L

Class org.apache.webbeans.annotation.EmptyAnnotationLiteral extends AnnotationLiteral<T extends Annotation> implements Serializable

Serialized Fields

annotationType

Class<T> annotationType

Class org.apache.webbeans.annotation.NamedLiteral extends AnnotationLiteral<Named> implements Serializable

serialVersionUID: 8867272511520063730L

Serialized Fields

value

String value

Class org.apache.webbeans.annotation.NewLiteral extends AnnotationLiteral<New> implements Serializable

serialVersionUID: -2981014729208063412L

Serialized Fields

clazz

Class<T> clazz

Class org.apache.webbeans.annotation.RequestedScopeLiteral extends EmptyAnnotationLiteral<RequestScoped> implements Serializable

serialVersionUID: -7333612898060695008L

Class org.apache.webbeans.annotation.SessionScopeLiteral extends EmptyAnnotationLiteral<SessionScoped> implements Serializable

serialVersionUID: -7469945140661485990L


Package org.apache.webbeans.component

Class org.apache.webbeans.component.ResourceProvider extends Object implements Serializable

Serialization Methods

readResolve

Object readResolve()
             throws ObjectStreamException
Throws:
ObjectStreamException
Serialized Fields

resourceReference

ResourceReference<X,T extends Annotation> resourceReference

Package org.apache.webbeans.container

Class org.apache.webbeans.container.InjectableBeanManager extends AbstractBeanManager implements Serializable

serialVersionUID: 1L

Serialization Methods

readExternal

public void readExternal(ObjectInput in)
                  throws IOException,
                         ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeExternal

public void writeExternal(ObjectOutput out)
                   throws IOException
Throws:
IOException

Class org.apache.webbeans.container.SerializableBean extends Object implements Serializable

serialVersionUID: -8141263188006177021L

Serialization Methods

readObject

private void readObject(ObjectInputStream s)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream s)
                  throws IOException
Throws:
IOException
Serialized Fields

bean

Bean<T> bean
the delegated bean


Package org.apache.webbeans.context

Class org.apache.webbeans.context.AbstractContext extends Object implements Serializable

serialVersionUID: 2357678967444477818L

Serialization Methods

readObject

private void readObject(ObjectInputStream s)
                 throws IOException,
                        ClassNotFoundException
Read object.

Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream s)
                  throws IOException
Write Object.

Throws:
IOException
Serialized Fields

active

boolean active
Context status, active or not


componentInstanceMap

Map<K,V> componentInstanceMap
Context contextual instances


scopeType

Class<T> scopeType
Contextual Scope Type

Class org.apache.webbeans.context.ApplicationContext extends AbstractContext implements Serializable

serialVersionUID: -8254441824647652312L

Class org.apache.webbeans.context.ConversationContext extends AbstractContext implements Serializable

serialVersionUID: -576054696008715282L

Serialization Methods

readExternal

public void readExternal(ObjectInput in)
                  throws IOException,
                         ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeExternal

public void writeExternal(ObjectOutput out)
                   throws IOException
Throws:
IOException

Class org.apache.webbeans.context.DependentContext extends AbstractContext implements Serializable

serialVersionUID: 8225241216057316441L

Class org.apache.webbeans.context.RequestContext extends AbstractContext implements Serializable

serialVersionUID: -1030240915163272268L

Class org.apache.webbeans.context.SessionContext extends AbstractContext implements Serializable

serialVersionUID: 1L

Serialization Methods

readExternal

public void readExternal(ObjectInput in)
                  throws IOException,
                         ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeExternal

public void writeExternal(ObjectOutput out)
                   throws IOException
Throws:
IOException

Class org.apache.webbeans.context.SingletonContext extends AbstractContext implements Serializable

serialVersionUID: -7600942820719243149L


Package org.apache.webbeans.context.creational

Class org.apache.webbeans.context.creational.BeanInstanceBag extends Object implements Serializable

serialVersionUID: 1656996021599122499L

Serialized Fields

beanCreationalContext

CreationalContext<T> beanCreationalContext

beanInstance

Object beanInstance

lock

Lock lock

Class org.apache.webbeans.context.creational.CreationalContextImpl extends Object implements Serializable

serialVersionUID: 1L

Serialization Methods

readObject

private void readObject(ObjectInputStream s)
                 throws IOException,
                        ClassNotFoundException
Read object.

Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream s)
                  throws IOException
Write Object.

Throws:
IOException
Serialized Fields

dependentObjects

List<E> dependentObjects
Contextual bean dependent instances

ATTENTION This variable gets initiated lazily!


bean

Bean<T> bean
Contains the currently created bean


contextual

Contextual<T> contextual
Contains the currently created contextual, may be a bean, interceptor or decorator


webBeansContext

WebBeansContext webBeansContext

destroying

boolean destroying
This flag will get set to true to prevent recursive loops while destroying the CreationContext.

Class org.apache.webbeans.context.creational.DependentCreationalContext extends Object implements Serializable

serialVersionUID: 1L

Serialization Methods

readObject

private void readObject(ObjectInputStream s)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream s)
                  throws IOException
Throws:
IOException
Serialized Fields

contextual

Contextual<T> contextual

instance

Object instance

Package org.apache.webbeans.conversation

Class org.apache.webbeans.conversation.ConversationImpl extends Object implements Serializable

serialVersionUID: 8511063860333431722L

Serialization Methods

readObject

private void readObject(ObjectInputStream in)
                 throws IOException,
                        ClassNotFoundException
We need this for restoring our WebBeansContext on de-serialisation

Throws:
IOException
ClassNotFoundException
Serialized Fields

id

String id
Conversation id


isTransient

boolean isTransient
Transient or not. Transient conversations are destroyed at the end of JSF request


timeout

long timeout
Default timeout is 30mins


sessionId

String sessionId
Id of the session that this conversation is created


activeTime

long activeTime
Active duration of the conversation


inUsed

AtomicBoolean inUsed
This instance is under used


Package org.apache.webbeans.event

Class org.apache.webbeans.event.EventImpl extends Object implements Serializable

serialVersionUID: -9035218380365451350L

Serialization Methods

readObject

private void readObject(ObjectInputStream in)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream op)
                  throws IOException
Throws:
IOException
Serialized Fields

injectedBindings

Annotation[] injectedBindings
Event binding types


eventType

Type eventType
Event types


injectionPoint

InjectionPoint injectionPoint
injection point of the event


Package org.apache.webbeans.exception

Class org.apache.webbeans.exception.WebBeansConfigurationException extends DefinitionException implements Serializable

serialVersionUID: 1863095663133791175L

Class org.apache.webbeans.exception.WebBeansCreationException extends WebBeansException implements Serializable

serialVersionUID: 1863095663133791175L

Class org.apache.webbeans.exception.WebBeansDeploymentException extends DeploymentException implements Serializable

serialVersionUID: 1863095663133791175L

Class org.apache.webbeans.exception.WebBeansException extends RuntimeException implements Serializable

serialVersionUID: -3721839220664165557L

Serialized Fields

cause

Throwable cause

Package org.apache.webbeans.exception.definition

Class org.apache.webbeans.exception.definition.DuplicateDefinitionException extends DefinitionException implements Serializable

serialVersionUID: 2312285271502063304L


Package org.apache.webbeans.exception.inject

Class org.apache.webbeans.exception.inject.DefinitionException extends RuntimeException implements Serializable

serialVersionUID: -6261526411795328050L

Class org.apache.webbeans.exception.inject.DeploymentException extends RuntimeException implements Serializable

serialVersionUID: -6635290650256485602L

Class org.apache.webbeans.exception.inject.InconsistentSpecializationException extends DefinitionException implements Serializable

serialVersionUID: 5398575103682514128L

Class org.apache.webbeans.exception.inject.NullableDependencyException extends DeploymentException implements Serializable

serialVersionUID: -2226577224929251465L


Package org.apache.webbeans.inject.instance

Class org.apache.webbeans.inject.instance.InstanceImpl extends Object implements Serializable

serialVersionUID: -8401944412490389024L

Serialization Methods

readObject

private void readObject(ObjectInputStream in)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream op)
                  throws IOException
Throws:
IOException
Serialized Fields

injectionClazz

Type injectionClazz
Injected class type


injectionPoint

InjectionPoint injectionPoint
injection point, needed for injection into producer method and used to determine the BDA it was loaded from or null.


qualifierAnnotations

Set<E> qualifierAnnotations
Qualifier annotations appeared on the injection point


webBeansContext

WebBeansContext webBeansContext

parentCreationalContext

CreationalContextImpl<T> parentCreationalContext

Package org.apache.webbeans.intercept

Class org.apache.webbeans.intercept.ApplicationScopedBeanInterceptorHandler extends NormalScopedBeanInterceptorHandler implements Serializable

serialVersionUID: 1L

Class org.apache.webbeans.intercept.DecoratorHandler extends Object implements Serializable

Serialization Methods

readExternal

public void readExternal(ObjectInput in)
                  throws IOException,
                         ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeExternal

public void writeExternal(ObjectOutput out)
                   throws IOException
Throws:
IOException

Class org.apache.webbeans.intercept.DefaultInterceptorHandler extends Object implements Serializable

Serialization Methods

readExternal

public void readExternal(ObjectInput in)
                  throws IOException,
                         ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeExternal

public void writeExternal(ObjectOutput out)
                   throws IOException
Throws:
IOException

Class org.apache.webbeans.intercept.NormalScopedBeanInterceptorHandler extends Object implements Serializable

Serialization Methods

readResolve

protected Object readResolve()
                      throws ObjectStreamException
The following code gets generated into the proxy:
 Object writeReplace() throws ObjectStreamException
 {
     return provider;
 }
 

Throws:
ObjectStreamException
Serialized Fields

beanPassivationId

String beanPassivationId
The passivation if in case this is a PassivationCapable bean. we just keep this field for serializing it away


Package org.apache.webbeans.proxy

Class org.apache.webbeans.proxy.ProxyGenerationException extends RuntimeException implements Serializable



Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.