Serialized Form
|
Package org.apache.webbeans.annotation |
serialVersionUID: -8922048102786275371L
serialVersionUID: 8089948111744513390L
serialVersionUID: 6788272256977634238L
serialVersionUID: -2677299920840834714L
annotationType
Class<T> annotationType
serialVersionUID: 8867272511520063730L
value
String value
serialVersionUID: -2981014729208063412L
clazz
Class<T> clazz
serialVersionUID: -7333612898060695008L
serialVersionUID: -7469945140661485990L
|
Package org.apache.webbeans.component |
readResolve
Object readResolve()
throws ObjectStreamException
- Throws:
ObjectStreamException
resourceReference
ResourceReference<X,T extends Annotation> resourceReference
|
Package org.apache.webbeans.container |
serialVersionUID: 1L
readExternal
public void readExternal(ObjectInput in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeExternal
public void writeExternal(ObjectOutput out)
throws IOException
- Throws:
IOException
serialVersionUID: -8141263188006177021L
readObject
private void readObject(ObjectInputStream s)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream s)
throws IOException
- Throws:
IOException
bean
Bean<T> bean
- the delegated bean
|
Package org.apache.webbeans.context |
serialVersionUID: 2357678967444477818L
readObject
private void readObject(ObjectInputStream s)
throws IOException,
ClassNotFoundException
- Read object.
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream s)
throws IOException
- Write Object.
- Throws:
IOException
active
boolean active
- Context status, active or not
componentInstanceMap
Map<K,V> componentInstanceMap
- Context contextual instances
scopeType
Class<T> scopeType
- Contextual Scope Type
serialVersionUID: -8254441824647652312L
serialVersionUID: -576054696008715282L
readExternal
public void readExternal(ObjectInput in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeExternal
public void writeExternal(ObjectOutput out)
throws IOException
- Throws:
IOException
serialVersionUID: 8225241216057316441L
serialVersionUID: -1030240915163272268L
serialVersionUID: 1L
readExternal
public void readExternal(ObjectInput in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeExternal
public void writeExternal(ObjectOutput out)
throws IOException
- Throws:
IOException
serialVersionUID: -7600942820719243149L
|
Package org.apache.webbeans.context.creational |
serialVersionUID: 1656996021599122499L
beanCreationalContext
CreationalContext<T> beanCreationalContext
beanInstance
Object beanInstance
lock
Lock lock
serialVersionUID: 1L
readObject
private void readObject(ObjectInputStream s)
throws IOException,
ClassNotFoundException
- Read object.
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream s)
throws IOException
- Write Object.
- Throws:
IOException
dependentObjects
List<E> dependentObjects
- Contextual bean dependent instances
ATTENTION This variable gets initiated lazily!
bean
Bean<T> bean
- Contains the currently created bean
contextual
Contextual<T> contextual
- Contains the currently created contextual, may be a bean, interceptor or decorator
webBeansContext
WebBeansContext webBeansContext
destroying
boolean destroying
- This flag will get set to
true to prevent recursive loops while destroying
the CreationContext.
serialVersionUID: 1L
readObject
private void readObject(ObjectInputStream s)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream s)
throws IOException
- Throws:
IOException
contextual
Contextual<T> contextual
instance
Object instance
|
Package org.apache.webbeans.conversation |
serialVersionUID: 8511063860333431722L
readObject
private void readObject(ObjectInputStream in)
throws IOException,
ClassNotFoundException
- We need this for restoring our WebBeansContext on de-serialisation
- Throws:
IOException
ClassNotFoundException
id
String id
- Conversation id
isTransient
boolean isTransient
- Transient or not. Transient conversations are destroyed at the end of JSF request
timeout
long timeout
- Default timeout is 30mins
sessionId
String sessionId
- Id of the session that this conversation is created
activeTime
long activeTime
- Active duration of the conversation
inUsed
AtomicBoolean inUsed
- This instance is under used
|
Package org.apache.webbeans.event |
serialVersionUID: -9035218380365451350L
readObject
private void readObject(ObjectInputStream in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream op)
throws IOException
- Throws:
IOException
injectedBindings
Annotation[] injectedBindings
- Event binding types
eventType
Type eventType
- Event types
injectionPoint
InjectionPoint injectionPoint
- injection point of the event
|
Package org.apache.webbeans.exception |
serialVersionUID: 1863095663133791175L
serialVersionUID: 1863095663133791175L
serialVersionUID: 1863095663133791175L
serialVersionUID: -3721839220664165557L
cause
Throwable cause
|
Package org.apache.webbeans.exception.definition |
serialVersionUID: 2312285271502063304L
|
Package org.apache.webbeans.exception.inject |
serialVersionUID: -6261526411795328050L
serialVersionUID: -6635290650256485602L
serialVersionUID: 5398575103682514128L
serialVersionUID: -2226577224929251465L
|
Package org.apache.webbeans.inject.instance |
serialVersionUID: -8401944412490389024L
readObject
private void readObject(ObjectInputStream in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream op)
throws IOException
- Throws:
IOException
injectionClazz
Type injectionClazz
- Injected class type
injectionPoint
InjectionPoint injectionPoint
- injection point, needed for injection into producer method and used to determine the BDA it was loaded from or null.
qualifierAnnotations
Set<E> qualifierAnnotations
- Qualifier annotations appeared on the injection point
webBeansContext
WebBeansContext webBeansContext
parentCreationalContext
CreationalContextImpl<T> parentCreationalContext
|
Package org.apache.webbeans.intercept |
serialVersionUID: 1L
readExternal
public void readExternal(ObjectInput in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeExternal
public void writeExternal(ObjectOutput out)
throws IOException
- Throws:
IOException
readExternal
public void readExternal(ObjectInput in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeExternal
public void writeExternal(ObjectOutput out)
throws IOException
- Throws:
IOException
readResolve
protected Object readResolve()
throws ObjectStreamException
- The following code gets generated into the proxy:
Object writeReplace() throws ObjectStreamException
{
return provider;
}
- Throws:
ObjectStreamException
beanPassivationId
String beanPassivationId
- The passivation if in case this is a
PassivationCapable bean.
we just keep this field for serializing it away
|
Package org.apache.webbeans.proxy |
Copyright © 2008–2014 The Apache Software Foundation. All rights reserved.